/**
 * @file btdrv_ids.h
 * @brief Bluetooth SIG assigned number definitions (see https://www.bluetooth.com/specifications/assigned-numbers/).
 * @author ndeadly
 * @copyright libnx Authors
 */
#pragma once

/// Extract \ref BtdrvAppearanceCategoryType from \ref BtdrvAppearanceType.
#define APPEARANCE_CATEGORY(x) ((x & 0xFFC0) >> 6)

/// AdType
typedef enum {
    BtdrvAdType_Flags                                        = 0x01,    ///< Flags
    BtdrvAdType_ServiceClassUuid16ListIncomplete             = 0x02,    ///< Incomplete List of 16-bit Service Class UUIDs
    BtdrvAdType_ServiceClassUuid16ListComplete 	             = 0x03,    ///< Complete List of 16-bit Service Class UUIDs
    BtdrvAdType_ServiceClassUuid32ListIncomplete             = 0x04,    ///< Incomplete List of 32-bit Service Class UUIDs
    BtdrvAdType_ServiceClassUuid32ListComplete               = 0x05,    ///< Complete List of 32-bit Service Class UUIDs
    BtdrvAdType_ServiceClassUuid128ListIncomplete            = 0x06,    ///< Incomplete List of 128-bit Service Class UUIDs
    BtdrvAdType_ServiceClassUuid128ListComplete              = 0x07,    ///< Complete List of 128-bit Service Class UUIDs
    BtdrvAdType_ShortenedLocalName                           = 0x08,    ///< Shortened Local Name
    BtdrvAdType_CompleteLocalName                            = 0x09,    ///< Complete Local Name
    BtdrvAdType_TxPowerLevel                                 = 0x0A,    ///< Tx Power Level
    BtdrvAdType_ClassOfDevice                                = 0x0D,    ///< Class of Device
    BtdrvAdType_SimplePairingHashC192                        = 0x0E,    ///< Simple Pairing Hash C-192
    BtdrvAdType_SimplePairingRandomizerR192                  = 0x0F,    ///< Simple Pairing Randomizer R-192
    BtdrvAdType_DeviceId                                     = 0x10,    ///< Device ID
    BtdrvAdType_SecurityManagerTkValue                       = 0x10,    ///< Security Manager TK Value
    BtdrvAdType_SecurityManagerOutOfBandFlags                = 0x11,    ///< Security Manager Out of Band Flags
    BtdrvAdType_PeripheralConnectionIntervalRange            = 0x12,    ///< Peripheral Connection Interval Range
    BtdrvAdType_ServiceSolicitationUuid16List                = 0x14,    ///< List of 16-bit Service Solicitation UUIDs
    BtdrvAdType_ServiceSolicitationUuid128List               = 0x15,    ///< List of 128-bit Service Solicitation UUIDs
    BtdrvAdType_ServiceDataUuid16                            = 0x16,    ///< Service Data - 16-bit UUID
    BtdrvAdType_PublicTargetAddress                          = 0x17,    ///< Public Target Address
    BtdrvAdType_RandomTargetAddress                          = 0x18,    ///< Random Target Address
    BtdrvAdType_Appearance                                   = 0x19,    ///< Appearance
    BtdrvAdType_AdvertisingInterval                          = 0x1A,    ///< Advertising Interval
    BtdrvAdType_LeBluetoothDeviceAddress                     = 0x1B,    ///< LE Bluetooth Device Address
    BtdrvAdType_LeRole                                       = 0x1C,    ///< LE Role
    BtdrvAdType_SimplePairingHashC256                        = 0x1D,    ///< Simple Pairing Hash C-256
    BtdrvAdType_SimplePairingRandomizerR256                  = 0x1E,    ///< Simple Pairing Randomizer R-256
    BtdrvAdType_ServiceSolicitationUuid32List                = 0x1F,    ///< List of 32-bit Service Solicitation UUIDs
    BtdrvAdType_ServiceDataUuid32                            = 0x20,    ///< Service Data - 32-bit UUID
    BtdrvAdType_ServiceDataUuid128                           = 0x21,    ///< Service Data - 128-bit UUID
    BtdrvAdType_LeSecureConnectionsConfirmationValue         = 0x22,    ///< LE Secure Connections Confirmation Value
    BtdrvAdType_LeSecureConnectionsRandomValue               = 0x23,    ///< LE Secure Connections Random Value
    BtdrvAdType_Uri                                          = 0x24,    ///< URI
    BtdrvAdType_IndoorPositioning                            = 0x25,    ///< Indoor Positioning
    BtdrvAdType_TransportDiscoveryData                       = 0x26,    ///< Transport Discovery Data
    BtdrvAdType_LeSupportedFeatures                          = 0x27,    ///< LE Supported Features
    BtdrvAdType_ChannelMapUpdateIndication                   = 0x28,    ///< Channel Map Update Indication
    BtdrvAdType_PbAdv                                        = 0x29,    ///< PB-ADV
    BtdrvAdType_MeshMessage                                  = 0x2A,    ///< Mesh Message
    BtdrvAdType_MeshBeacon                                   = 0x2B,    ///< Mesh Beacon
    BtdrvAdType_Biginfo                                      = 0x2C,    ///< BIGInfo
    BtdrvAdType_BroadcastCode                                = 0x2D,    ///< Broadcast_Code
    BtdrvAdType_ResolvableSetIdentifier                      = 0x2E,    ///< Resolvable Set Identifier
    BtdrvAdType_AdvertisingIntervalLong                      = 0x2F,    ///< Advertising Interval - long
    BtdrvAdType_BroadcastName                                = 0x30,    ///< Broadcast_Name
    BtdrvAdType_EncryptedAdvertisingData                     = 0x31,    ///< Encrypted Advertising Data
    BtdrvAdType_PeriodicAdvertisingResponseTimingInformation = 0x32,    ///< Periodic Advertising Response Timing Information
    BtdrvAdType_ElectronicShelfLabel                         = 0x34,    ///< Electronic Shelf Label
    BtdrvAdType_3DInformationData                            = 0x3D,    ///< 3D Information Data
    BtdrvAdType_ManufacturerSpecificData                     = 0xFF,    ///< Manufacturer Specific Data
} BtdrvAdType;

/// AppearanceCategoryType
typedef enum {
    BtdrvAppearanceCategoryType_Unknown                  = 0x000,    ///< Unknown
    BtdrvAppearanceCategoryType_Phone                    = 0x001,    ///< Phone
    BtdrvAppearanceCategoryType_Computer                 = 0x002,    ///< Computer
    BtdrvAppearanceCategoryType_Watch                    = 0x003,    ///< Watch
    BtdrvAppearanceCategoryType_Clock                    = 0x004,    ///< Clock
    BtdrvAppearanceCategoryType_Display                  = 0x005,    ///< Display
    BtdrvAppearanceCategoryType_RemoteControl            = 0x006,    ///< Remote Control
    BtdrvAppearanceCategoryType_EyeGlasses               = 0x007,    ///< Eye-glasses
    BtdrvAppearanceCategoryType_Tag                      = 0x008,    ///< Tag
    BtdrvAppearanceCategoryType_Keyring                  = 0x009,    ///< Keyring
    BtdrvAppearanceCategoryType_MediaPlayer              = 0x00A,    ///< Media Player
    BtdrvAppearanceCategoryType_BarcodeScanner           = 0x00B,    ///< Barcode Scanner
    BtdrvAppearanceCategoryType_Thermometer              = 0x00C,    ///< Thermometer
    BtdrvAppearanceCategoryType_HeartRateSensor          = 0x00D,    ///< Heart Rate Sensor
    BtdrvAppearanceCategoryType_BloodPressure            = 0x00E,    ///< Blood Pressure
    BtdrvAppearanceCategoryType_HumanInterfaceDevice     = 0x00F,    ///< Human Interface Device
    BtdrvAppearanceCategoryType_GlucoseMeter             = 0x010,    ///< Glucose Meter
    BtdrvAppearanceCategoryType_RunningWalkingSensor     = 0x011,    ///< Running Walking Sensor
    BtdrvAppearanceCategoryType_Cycling                  = 0x012,    ///< Cycling
    BtdrvAppearanceCategoryType_ControlDevice            = 0x013,    ///< Control Device
    BtdrvAppearanceCategoryType_NetworkDevice            = 0x014,    ///< Network Device
    BtdrvAppearanceCategoryType_Sensor                   = 0x015,    ///< Sensor
    BtdrvAppearanceCategoryType_LightFixtures            = 0x016,    ///< Light Fixtures
    BtdrvAppearanceCategoryType_Fan                      = 0x017,    ///< Fan
    BtdrvAppearanceCategoryType_Hvac                     = 0x018,    ///< HVAC
    BtdrvAppearanceCategoryType_AirConditioning          = 0x019,    ///< Air Conditioning
    BtdrvAppearanceCategoryType_Humidifier               = 0x01A,    ///< Humidifier
    BtdrvAppearanceCategoryType_Heating                  = 0x01B,    ///< Heating
    BtdrvAppearanceCategoryType_AccessControl            = 0x01C,    ///< Access Control
    BtdrvAppearanceCategoryType_MotorizedDevice          = 0x01D,    ///< Motorized Device
    BtdrvAppearanceCategoryType_PowerDevice              = 0x01E,    ///< Power Device
    BtdrvAppearanceCategoryType_LightSource              = 0x01F,    ///< Light Source
    BtdrvAppearanceCategoryType_WindowCovering           = 0x020,    ///< Window Covering
    BtdrvAppearanceCategoryType_AudioSink                = 0x021,    ///< Audio Sink
    BtdrvAppearanceCategoryType_AudioSource              = 0x022,    ///< Audio Source
    BtdrvAppearanceCategoryType_MotorizedVehicle         = 0x023,    ///< Motorized Vehicle
    BtdrvAppearanceCategoryType_DomesticAppliance        = 0x024,    ///< Domestic Appliance
    BtdrvAppearanceCategoryType_WearableAudioDevice      = 0x025,    ///< Wearable Audio Device
    BtdrvAppearanceCategoryType_Aircraft                 = 0x026,    ///< Aircraft
    BtdrvAppearanceCategoryType_AvEquipment              = 0x027,    ///< AV Equipment
    BtdrvAppearanceCategoryType_DisplayEquipment         = 0x028,    ///< Display Equipment
    BtdrvAppearanceCategoryType_HearingAid               = 0x029,    ///< Hearing aid
    BtdrvAppearanceCategoryType_Gaming                   = 0x02A,    ///< Gaming
    BtdrvAppearanceCategoryType_PulseOximeter            = 0x031,    ///< Pulse Oximeter
    BtdrvAppearanceCategoryType_WeightScale              = 0x032,    ///< Weight Scale
    BtdrvAppearanceCategoryType_PersonalMobilityDevice   = 0x033,    ///< Personal Mobility Device
    BtdrvAppearanceCategoryType_ContinuousGlucoseMonitor = 0x034,    ///< Continuous Glucose Monitor
    BtdrvAppearanceCategoryType_InsulinPump              = 0x035,    ///< Insulin Pump
    BtdrvAppearanceCategoryType_MedicationDelivery       = 0x036,    ///< Medication Delivery
    BtdrvAppearanceCategoryType_Spirometer               = 0x037,    ///< Spirometer
    BtdrvAppearanceCategoryType_OutdoorSportsActivity    = 0x051,    ///< Outdoor Sports Activity
} BtdrvAppearanceCategoryType;

/// AppearanceType
typedef enum {
    BtdrvAppearanceType_DesktopWorkstation              = 0x0081,    ///< Desktop Workstation
    BtdrvAppearanceType_ServerClassComputer             = 0x0082,    ///< Server-class Computer
    BtdrvAppearanceType_Laptop                          = 0x0083,    ///< Laptop
    BtdrvAppearanceType_HandheldPcPdaClamshell          = 0x0084,    ///< Handheld PC/PDA (clamshell)
    BtdrvAppearanceType_PalmSizePcPda                   = 0x0085,    ///< Palm-size PC/PDA
    BtdrvAppearanceType_WearableComputerWatchSize       = 0x0086,    ///< Wearable computer (watch size)
    BtdrvAppearanceType_Tablet                          = 0x0087,    ///< Tablet
    BtdrvAppearanceType_DockingStation                  = 0x0088,    ///< Docking Station
    BtdrvAppearanceType_AllInOne                        = 0x0089,    ///< All in One
    BtdrvAppearanceType_BladeServer                     = 0x008A,    ///< Blade Server
    BtdrvAppearanceType_Convertible                     = 0x008B,    ///< Convertible
    BtdrvAppearanceType_Detachable                      = 0x008C,    ///< Detachable
    BtdrvAppearanceType_IotGateway                      = 0x008D,    ///< IoT Gateway
    BtdrvAppearanceType_MiniPc                          = 0x008E,    ///< Mini PC
    BtdrvAppearanceType_StickPc                         = 0x008F,    ///< Stick PC
    BtdrvAppearanceType_SportsWatch                     = 0x00C1,    ///< Sports Watch
    BtdrvAppearanceType_Smartwatch                      = 0x00C2,    ///< Smartwatch
    BtdrvAppearanceType_EarThermometer                  = 0x0301,    ///< Ear Thermometer
    BtdrvAppearanceType_HeartRateBelt                   = 0x0341,    ///< Heart Rate Belt
    BtdrvAppearanceType_ArmBloodPressure                = 0x0381,    ///< Arm Blood Pressure
    BtdrvAppearanceType_WristBloodPressure              = 0x0382,    ///< Wrist Blood Pressure
    BtdrvAppearanceType_Keyboard                        = 0x03C1,    ///< Keyboard
    BtdrvAppearanceType_Mouse                           = 0x03C2,    ///< Mouse
    BtdrvAppearanceType_Joystick                        = 0x03C3,    ///< Joystick
    BtdrvAppearanceType_Gamepad                         = 0x03C4,    ///< Gamepad
    BtdrvAppearanceType_DigitizerTablet                 = 0x03C5,    ///< Digitizer Tablet
    BtdrvAppearanceType_CardReader                      = 0x03C6,    ///< Card Reader
    BtdrvAppearanceType_DigitalPen                      = 0x03C7,    ///< Digital Pen
    BtdrvAppearanceType_BarcodeScanner                  = 0x03C8,    ///< Barcode Scanner
    BtdrvAppearanceType_Touchpad                        = 0x03C9,    ///< Touchpad
    BtdrvAppearanceType_PresentationRemote              = 0x03CA,    ///< Presentation Remote
    BtdrvAppearanceType_InShoeRunningWalkingSensor      = 0x0441,    ///< In-Shoe Running Walking Sensor
    BtdrvAppearanceType_OnShoeRunningWalkingSensor      = 0x0442,    ///< On-Shoe Running Walking Sensor
    BtdrvAppearanceType_OnHipRunningWalkingSensor       = 0x0443,    ///< On-Hip Running Walking Sensor
    BtdrvAppearanceType_CyclingComputer                 = 0x0481,    ///< Cycling Computer
    BtdrvAppearanceType_SpeedSensor                     = 0x0482,    ///< Speed Sensor
    BtdrvAppearanceType_CadenceSensor                   = 0x0483,    ///< Cadence Sensor
    BtdrvAppearanceType_PowerSensor                     = 0x0484,    ///< Power Sensor
    BtdrvAppearanceType_SpeedAndCadenceSensor           = 0x0485,    ///< Speed and Cadence Sensor
    BtdrvAppearanceType_Switch                          = 0x04C1,    ///< Switch
    BtdrvAppearanceType_MultiSwitch                     = 0x04C2,    ///< Multi-switch
    BtdrvAppearanceType_Button                          = 0x04C3,    ///< Button
    BtdrvAppearanceType_Slider                          = 0x04C4,    ///< Slider
    BtdrvAppearanceType_RotarySwitch                    = 0x04C5,    ///< Rotary Switch
    BtdrvAppearanceType_TouchPanel                      = 0x04C6,    ///< Touch Panel
    BtdrvAppearanceType_SingleSwitch                    = 0x04C7,    ///< Single Switch
    BtdrvAppearanceType_DoubleSwitch                    = 0x04C8,    ///< Double Switch
    BtdrvAppearanceType_TripleSwitch                    = 0x04C9,    ///< Triple Switch
    BtdrvAppearanceType_BatterySwitch                   = 0x04CA,    ///< Battery Switch
    BtdrvAppearanceType_EnergyHarvestingSwitch          = 0x04CB,    ///< Energy Harvesting Switch
    BtdrvAppearanceType_PushButton                      = 0x04CC,    ///< Push Button
    BtdrvAppearanceType_AccessPoint                     = 0x0501,    ///< Access Point
    BtdrvAppearanceType_MeshDevice                      = 0x0502,    ///< Mesh Device
    BtdrvAppearanceType_MeshNetworkProxy                = 0x0503,    ///< Mesh Network Proxy
    BtdrvAppearanceType_MotionSensor                    = 0x0541,    ///< Motion Sensor
    BtdrvAppearanceType_AirQualitySensor                = 0x0542,    ///< Air quality Sensor
    BtdrvAppearanceType_TemperatureSensor               = 0x0543,    ///< Temperature Sensor
    BtdrvAppearanceType_HumiditySensor                  = 0x0544,    ///< Humidity Sensor
    BtdrvAppearanceType_LeakSensor                      = 0x0545,    ///< Leak Sensor
    BtdrvAppearanceType_SmokeSensor                     = 0x0546,    ///< Smoke Sensor
    BtdrvAppearanceType_OccupancySensor                 = 0x0547,    ///< Occupancy Sensor
    BtdrvAppearanceType_ContactSensor                   = 0x0548,    ///< Contact Sensor
    BtdrvAppearanceType_CarbonMonoxideSensor            = 0x0549,    ///< Carbon Monoxide Sensor
    BtdrvAppearanceType_CarbonDioxideSensor             = 0x054A,    ///< Carbon Dioxide Sensor
    BtdrvAppearanceType_AmbientLightSensor              = 0x054B,    ///< Ambient Light Sensor
    BtdrvAppearanceType_EnergySensor                    = 0x054C,    ///< Energy Sensor
    BtdrvAppearanceType_ColorLightSensor                = 0x054D,    ///< Color Light Sensor
    BtdrvAppearanceType_RainSensor                      = 0x054E,    ///< Rain Sensor
    BtdrvAppearanceType_FireSensor                      = 0x054F,    ///< Fire Sensor
    BtdrvAppearanceType_WindSensor                      = 0x0550,    ///< Wind Sensor
    BtdrvAppearanceType_ProximitySensor                 = 0x0551,    ///< Proximity Sensor
    BtdrvAppearanceType_MultiSensor                     = 0x0552,    ///< Multi-Sensor
    BtdrvAppearanceType_FlushMountedSensor              = 0x0553,    ///< Flush Mounted Sensor
    BtdrvAppearanceType_CeilingMountedSensor            = 0x0554,    ///< Ceiling Mounted Sensor
    BtdrvAppearanceType_WallMountedSensor               = 0x0555,    ///< Wall Mounted Sensor
    BtdrvAppearanceType_Multisensor                     = 0x0556,    ///< Multisensor
    BtdrvAppearanceType_EnergyMeter                     = 0x0557,    ///< Energy Meter
    BtdrvAppearanceType_FlameDetector                   = 0x0558,    ///< Flame Detector
    BtdrvAppearanceType_VehicleTirePressureSensor       = 0x0559,    ///< Vehicle Tire Pressure Sensor
    BtdrvAppearanceType_WallLight                       = 0x0581,    ///< Wall Light
    BtdrvAppearanceType_CeilingLight                    = 0x0582,    ///< Ceiling Light
    BtdrvAppearanceType_FloorLight                      = 0x0583,    ///< Floor Light
    BtdrvAppearanceType_CabinetLight                    = 0x0584,    ///< Cabinet Light
    BtdrvAppearanceType_DeskLight                       = 0x0585,    ///< Desk Light
    BtdrvAppearanceType_TrofferLight                    = 0x0586,    ///< Troffer Light
    BtdrvAppearanceType_PendantLight                    = 0x0587,    ///< Pendant Light
    BtdrvAppearanceType_InGroundLight                   = 0x0588,    ///< In-ground Light
    BtdrvAppearanceType_FloodLight                      = 0x0589,    ///< Flood Light
    BtdrvAppearanceType_UnderwaterLight                 = 0x058A,    ///< Underwater Light
    BtdrvAppearanceType_BollardWithLight                = 0x058B,    ///< Bollard with Light
    BtdrvAppearanceType_PathwayLight                    = 0x058C,    ///< Pathway Light
    BtdrvAppearanceType_GardenLight                     = 0x058D,    ///< Garden Light
    BtdrvAppearanceType_PoleTopLight                    = 0x058E,    ///< Pole-top Light
    BtdrvAppearanceType_Spotlight                       = 0x058F,    ///< Spotlight
    BtdrvAppearanceType_LinearLight                     = 0x0590,    ///< Linear Light
    BtdrvAppearanceType_StreetLight                     = 0x0591,    ///< Street Light
    BtdrvAppearanceType_ShelvesLight                    = 0x0592,    ///< Shelves Light
    BtdrvAppearanceType_BayLight                        = 0x0593,    ///< Bay Light
    BtdrvAppearanceType_EmergencyExitLight              = 0x0594,    ///< Emergency Exit Light
    BtdrvAppearanceType_LightController                 = 0x0595,    ///< Light Controller
    BtdrvAppearanceType_LightDriver                     = 0x0596,    ///< Light Driver
    BtdrvAppearanceType_Bulb                            = 0x0597,    ///< Bulb
    BtdrvAppearanceType_LowBayLight                     = 0x0598,    ///< Low-bay Light
    BtdrvAppearanceType_HighBayLight                    = 0x0599,    ///< High-bay Light
    BtdrvAppearanceType_CeilingFan                      = 0x05C1,    ///< Ceiling Fan
    BtdrvAppearanceType_AxialFan                        = 0x05C2,    ///< Axial Fan
    BtdrvAppearanceType_ExhaustFan                      = 0x05C3,    ///< Exhaust Fan
    BtdrvAppearanceType_PedestalFan                     = 0x05C4,    ///< Pedestal Fan
    BtdrvAppearanceType_DeskFan                         = 0x05C5,    ///< Desk Fan
    BtdrvAppearanceType_WallFan                         = 0x05C6,    ///< Wall Fan
    BtdrvAppearanceType_Thermostat                      = 0x0601,    ///< Thermostat
    BtdrvAppearanceType_Humidifier                      = 0x0602,    ///< Humidifier
    BtdrvAppearanceType_DeHumidifier                    = 0x0603,    ///< De-humidifier
    BtdrvAppearanceType_Heater                          = 0x0604,    ///< Heater
    BtdrvAppearanceType_HvacRadiator                    = 0x0605,    ///< HVAC Radiator
    BtdrvAppearanceType_HvacBoiler                      = 0x0606,    ///< HVAC Boiler
    BtdrvAppearanceType_HvacHeatPump                    = 0x0607,    ///< HVAC Heat Pump
    BtdrvAppearanceType_HvacInfraredHeater              = 0x0608,    ///< HVAC Infrared Heater
    BtdrvAppearanceType_HvacRadiantPanelHeater          = 0x0609,    ///< HVAC Radiant Panel Heater
    BtdrvAppearanceType_HvacFanHeater                   = 0x060A,    ///< HVAC Fan Heater
    BtdrvAppearanceType_HvacAirCurtain                  = 0x060B,    ///< HVAC Air Curtain
    BtdrvAppearanceType_HeatingRadiator                 = 0x06C1,    ///< Heating Radiator
    BtdrvAppearanceType_HeatingBoiler                   = 0x06C2,    ///< Heating Boiler
    BtdrvAppearanceType_HeatingHeatPump                 = 0x06C3,    ///< Heating Heat Pump
    BtdrvAppearanceType_HeatingInfraredHeater           = 0x06C4,    ///< Heating Infrared Heater
    BtdrvAppearanceType_HeatingRadiantPanelHeater       = 0x06C5,    ///< Heating Radiant Panel Heater
    BtdrvAppearanceType_HeatingFanHeater                = 0x06C6,    ///< Heating Fan Heater
    BtdrvAppearanceType_HeatingAirCurtain               = 0x06C7,    ///< Heating Air Curtain
    BtdrvAppearanceType_AccessDoor                      = 0x0701,    ///< Access Door
    BtdrvAppearanceType_GarageDoor                      = 0x0702,    ///< Garage Door
    BtdrvAppearanceType_EmergencyExitDoor               = 0x0703,    ///< Emergency Exit Door
    BtdrvAppearanceType_AccessLock                      = 0x0704,    ///< Access Lock
    BtdrvAppearanceType_Elevator                        = 0x0705,    ///< Elevator
    BtdrvAppearanceType_Window                          = 0x0706,    ///< Window
    BtdrvAppearanceType_EntranceGate                    = 0x0707,    ///< Entrance Gate
    BtdrvAppearanceType_DoorLock                        = 0x0708,    ///< Door Lock
    BtdrvAppearanceType_Locker                          = 0x0709,    ///< Locker
    BtdrvAppearanceType_MotorizedGate                   = 0x0741,    ///< Motorized Gate
    BtdrvAppearanceType_Awning                          = 0x0742,    ///< Awning
    BtdrvAppearanceType_BlindsOrShades                  = 0x0743,    ///< Blinds or Shades
    BtdrvAppearanceType_Curtains                        = 0x0744,    ///< Curtains
    BtdrvAppearanceType_Screen                          = 0x0745,    ///< Screen
    BtdrvAppearanceType_PowerOutlet                     = 0x0781,    ///< Power Outlet
    BtdrvAppearanceType_PowerStrip                      = 0x0782,    ///< Power Strip
    BtdrvAppearanceType_Plug                            = 0x0783,    ///< Plug
    BtdrvAppearanceType_PowerSupply                     = 0x0784,    ///< Power Supply
    BtdrvAppearanceType_LedDriver                       = 0x0785,    ///< LED Driver
    BtdrvAppearanceType_FluorescentLampGear             = 0x0786,    ///< Fluorescent Lamp Gear
    BtdrvAppearanceType_HidLampGear                     = 0x0787,    ///< HID Lamp Gear
    BtdrvAppearanceType_ChargeCase                      = 0x0788,    ///< Charge Case
    BtdrvAppearanceType_PowerBank                       = 0x0789,    ///< Power Bank
    BtdrvAppearanceType_IncandescentLightBulb           = 0x07C1,    ///< Incandescent Light Bulb
    BtdrvAppearanceType_LedLamp                         = 0x07C2,    ///< LED Lamp
    BtdrvAppearanceType_HidLamp                         = 0x07C3,    ///< HID Lamp
    BtdrvAppearanceType_FluorescentLamp                 = 0x07C4,    ///< Fluorescent Lamp
    BtdrvAppearanceType_LedArray                        = 0x07C5,    ///< LED Array
    BtdrvAppearanceType_MultiColorLedArray              = 0x07C6,    ///< Multi-Color LED Array
    BtdrvAppearanceType_LowVoltageHalogen               = 0x07C7,    ///< Low voltage halogen
    BtdrvAppearanceType_OrganicLightEmittingDiodeOled   = 0x07C8,    ///< Organic light emitting diode (OLED)
    BtdrvAppearanceType_WindowShades                    = 0x0801,    ///< Window Shades
    BtdrvAppearanceType_WindowBlinds                    = 0x0802,    ///< Window Blinds
    BtdrvAppearanceType_WindowAwning                    = 0x0803,    ///< Window Awning
    BtdrvAppearanceType_WindowCurtain                   = 0x0804,    ///< Window Curtain
    BtdrvAppearanceType_ExteriorShutter                 = 0x0805,    ///< Exterior Shutter
    BtdrvAppearanceType_ExteriorScreen                  = 0x0806,    ///< Exterior Screen
    BtdrvAppearanceType_StandaloneSpeaker               = 0x0841,    ///< Standalone Speaker
    BtdrvAppearanceType_Soundbar                        = 0x0842,    ///< Soundbar
    BtdrvAppearanceType_BookshelfSpeaker                = 0x0843,    ///< Bookshelf Speaker
    BtdrvAppearanceType_StandmountedSpeaker             = 0x0844,    ///< Standmounted Speaker
    BtdrvAppearanceType_Speakerphone                    = 0x0845,    ///< Speakerphone
    BtdrvAppearanceType_Microphone                      = 0x0881,    ///< Microphone
    BtdrvAppearanceType_Alarm                           = 0x0882,    ///< Alarm
    BtdrvAppearanceType_Bell                            = 0x0883,    ///< Bell
    BtdrvAppearanceType_Horn                            = 0x0884,    ///< Horn
    BtdrvAppearanceType_BroadcastingDevice              = 0x0885,    ///< Broadcasting Device
    BtdrvAppearanceType_ServiceDesk                     = 0x0886,    ///< Service Desk
    BtdrvAppearanceType_Kiosk                           = 0x0887,    ///< Kiosk
    BtdrvAppearanceType_BroadcastingRoom                = 0x0888,    ///< Broadcasting Room
    BtdrvAppearanceType_Auditorium                      = 0x0889,    ///< Auditorium
    BtdrvAppearanceType_Car                             = 0x08C1,    ///< Car
    BtdrvAppearanceType_LargeGoodsVehicle               = 0x08C2,    ///< Large Goods Vehicle
    BtdrvAppearanceType_2WheeledVehicle                 = 0x08C3,    ///< 2-Wheeled Vehicle
    BtdrvAppearanceType_Motorbike                       = 0x08C4,    ///< Motorbike
    BtdrvAppearanceType_Scooter                         = 0x08C5,    ///< Scooter
    BtdrvAppearanceType_Moped                           = 0x08C6,    ///< Moped
    BtdrvAppearanceType_3WheeledVehicle                 = 0x08C7,    ///< 3-Wheeled Vehicle
    BtdrvAppearanceType_LightVehicle                    = 0x08C8,    ///< Light Vehicle
    BtdrvAppearanceType_QuadBike                        = 0x08C9,    ///< Quad Bike
    BtdrvAppearanceType_Minibus                         = 0x08CA,    ///< Minibus
    BtdrvAppearanceType_Bus                             = 0x08CB,    ///< Bus
    BtdrvAppearanceType_Trolley                         = 0x08CC,    ///< Trolley
    BtdrvAppearanceType_AgriculturalVehicle             = 0x08CD,    ///< Agricultural Vehicle
    BtdrvAppearanceType_CamperCaravan                   = 0x08CE,    ///< Camper / Caravan
    BtdrvAppearanceType_RecreationalVehicleMotorHome    = 0x08CF,    ///< Recreational Vehicle / Motor Home
    BtdrvAppearanceType_Refrigerator                    = 0x0901,    ///< Refrigerator
    BtdrvAppearanceType_Freezer                         = 0x0902,    ///< Freezer
    BtdrvAppearanceType_Oven                            = 0x0903,    ///< Oven
    BtdrvAppearanceType_Microwave                       = 0x0904,    ///< Microwave
    BtdrvAppearanceType_Toaster                         = 0x0905,    ///< Toaster
    BtdrvAppearanceType_WashingMachine                  = 0x0906,    ///< Washing Machine
    BtdrvAppearanceType_Dryer                           = 0x0907,    ///< Dryer
    BtdrvAppearanceType_CoffeeMaker                     = 0x0908,    ///< Coffee maker
    BtdrvAppearanceType_ClothesIron                     = 0x0909,    ///< Clothes iron
    BtdrvAppearanceType_CurlingIron                     = 0x090A,    ///< Curling iron
    BtdrvAppearanceType_HairDryer                       = 0x090B,    ///< Hair dryer
    BtdrvAppearanceType_VacuumCleaner                   = 0x090C,    ///< Vacuum cleaner
    BtdrvAppearanceType_RoboticVacuumCleaner            = 0x090D,    ///< Robotic vacuum cleaner
    BtdrvAppearanceType_RiceCooker                      = 0x090E,    ///< Rice cooker
    BtdrvAppearanceType_ClothesSteamer                  = 0x090F,    ///< Clothes steamer
    BtdrvAppearanceType_Earbud                          = 0x0941,    ///< Earbud
    BtdrvAppearanceType_Headset                         = 0x0942,    ///< Headset
    BtdrvAppearanceType_Headphones                      = 0x0943,    ///< Headphones
    BtdrvAppearanceType_NeckBand                        = 0x0944,    ///< Neck Band
    BtdrvAppearanceType_LightAircraft                   = 0x0981,    ///< Light Aircraft
    BtdrvAppearanceType_Microlight                      = 0x0982,    ///< Microlight
    BtdrvAppearanceType_Paraglider                      = 0x0983,    ///< Paraglider
    BtdrvAppearanceType_LargePassengerAircraft          = 0x0984,    ///< Large Passenger Aircraft
    BtdrvAppearanceType_Amplifier                       = 0x09C1,    ///< Amplifier
    BtdrvAppearanceType_Receiver                        = 0x09C2,    ///< Receiver
    BtdrvAppearanceType_Radio                           = 0x09C3,    ///< Radio
    BtdrvAppearanceType_Tuner                           = 0x09C4,    ///< Tuner
    BtdrvAppearanceType_Turntable                       = 0x09C5,    ///< Turntable
    BtdrvAppearanceType_CdPlayer                        = 0x09C6,    ///< CD Player
    BtdrvAppearanceType_DvdPlayer                       = 0x09C7,    ///< DVD Player
    BtdrvAppearanceType_BlurayPlayer                    = 0x09C8,    ///< Bluray Player
    BtdrvAppearanceType_OpticalDiscPlayer               = 0x09C9,    ///< Optical Disc Player
    BtdrvAppearanceType_SetTopBox                       = 0x09CA,    ///< Set-Top Box
    BtdrvAppearanceType_Television                      = 0x0A01,    ///< Television
    BtdrvAppearanceType_Monitor                         = 0x0A02,    ///< Monitor
    BtdrvAppearanceType_Projector                       = 0x0A03,    ///< Projector
    BtdrvAppearanceType_InEarHearingAid                 = 0x0A41,    ///< In-ear hearing aid
    BtdrvAppearanceType_BehindEarHearingAid             = 0x0A42,    ///< Behind-ear hearing aid
    BtdrvAppearanceType_CochlearImplant                 = 0x0A43,    ///< Cochlear Implant
    BtdrvAppearanceType_HomeVideoGameConsole            = 0x0A81,    ///< Home Video Game Console
    BtdrvAppearanceType_PortableHandheldConsole         = 0x0A82,    ///< Portable handheld console
    BtdrvAppearanceType_FingertipPulseOximeter          = 0x0C41,    ///< Fingertip Pulse Oximeter
    BtdrvAppearanceType_WristWornPulseOximeter          = 0x0C42,    ///< Wrist Worn Pulse Oximeter
    BtdrvAppearanceType_PoweredWheelchair               = 0x0CC1,    ///< Powered Wheelchair
    BtdrvAppearanceType_MobilityScooter                 = 0x0CC2,    ///< Mobility Scooter
    BtdrvAppearanceType_InsulinPumpDurablePump          = 0x0D41,    ///< Insulin Pump, durable pump
    BtdrvAppearanceType_InsulinPumpPatchPump            = 0x0D44,    ///< Insulin Pump, patch pump
    BtdrvAppearanceType_InsulinPen                      = 0x0D48,    ///< Insulin Pen
    BtdrvAppearanceType_HandheldSpirometer              = 0x0DC1,    ///< Handheld Spirometer
    BtdrvAppearanceType_LocationDisplay                 = 0x1441,    ///< Location Display
    BtdrvAppearanceType_LocationAndNavigationDisplay    = 0x1442,    ///< Location and Navigation Display
    BtdrvAppearanceType_LocationPod                     = 0x1443,    ///< Location Pod
    BtdrvAppearanceType_LocationAndNavigationPod        = 0x1444,    ///< Location and Navigation Pod
} BtdrvAppearanceType;

/// GattServiceUuidType
typedef enum {
    BtdrvGattServiceUuidType_GenericAccess                = 0x1800,    ///< Generic Access
    BtdrvGattServiceUuidType_GenericAttribute             = 0x1801,    ///< Generic Attribute
    BtdrvGattServiceUuidType_ImmediateAlert               = 0x1802,    ///< Immediate Alert
    BtdrvGattServiceUuidType_LinkLoss                     = 0x1803,    ///< Link Loss
    BtdrvGattServiceUuidType_TxPower                      = 0x1804,    ///< Tx Power
    BtdrvGattServiceUuidType_CurrentTime                  = 0x1805,    ///< Current Time
    BtdrvGattServiceUuidType_ReferenceTimeUpdate          = 0x1806,    ///< Reference Time Update
    BtdrvGattServiceUuidType_NextDstChange                = 0x1807,    ///< Next DST Change
    BtdrvGattServiceUuidType_Glucose                      = 0x1808,    ///< Glucose
    BtdrvGattServiceUuidType_HealthThermometer            = 0x1809,    ///< Health Thermometer
    BtdrvGattServiceUuidType_DeviceInformation            = 0x180A,    ///< Device Information
    BtdrvGattServiceUuidType_HeartRate                    = 0x180D,    ///< Heart Rate
    BtdrvGattServiceUuidType_PhoneAlertStatus             = 0x180E,    ///< Phone Alert Status
    BtdrvGattServiceUuidType_Battery                      = 0x180F,    ///< Battery
    BtdrvGattServiceUuidType_BloodPressure                = 0x1810,    ///< Blood Pressure
    BtdrvGattServiceUuidType_AlertNotification            = 0x1811,    ///< Alert Notification
    BtdrvGattServiceUuidType_HumanInterfaceDevice         = 0x1812,    ///< Human Interface Device
    BtdrvGattServiceUuidType_ScanParameters               = 0x1813,    ///< Scan Parameters
    BtdrvGattServiceUuidType_RunningSpeedAndCadence       = 0x1814,    ///< Running Speed and Cadence
    BtdrvGattServiceUuidType_AutomationIo                 = 0x1815,    ///< Automation IO
    BtdrvGattServiceUuidType_CyclingSpeedAndCadence       = 0x1816,    ///< Cycling Speed and Cadence
    BtdrvGattServiceUuidType_CyclingPower                 = 0x1818,    ///< Cycling Power
    BtdrvGattServiceUuidType_LocationAndNavigation        = 0x1819,    ///< Location and Navigation
    BtdrvGattServiceUuidType_EnvironmentalSensing         = 0x181A,    ///< Environmental Sensing
    BtdrvGattServiceUuidType_BodyComposition              = 0x181B,    ///< Body Composition
    BtdrvGattServiceUuidType_UserData                     = 0x181C,    ///< User Data
    BtdrvGattServiceUuidType_WeightScale                  = 0x181D,    ///< Weight Scale
    BtdrvGattServiceUuidType_BondManagement               = 0x181E,    ///< Bond Management
    BtdrvGattServiceUuidType_ContinuousGlucoseMonitoring  = 0x181F,    ///< Continuous Glucose Monitoring
    BtdrvGattServiceUuidType_InternetProtocolSupport      = 0x1820,    ///< Internet Protocol Support
    BtdrvGattServiceUuidType_IndoorPositioning            = 0x1821,    ///< Indoor Positioning
    BtdrvGattServiceUuidType_PulseOximeter                = 0x1822,    ///< Pulse Oximeter
    BtdrvGattServiceUuidType_HttpProxy                    = 0x1823,    ///< HTTP Proxy
    BtdrvGattServiceUuidType_TransportDiscovery           = 0x1824,    ///< Transport Discovery
    BtdrvGattServiceUuidType_ObjectTransfer               = 0x1825,    ///< Object Transfer
    BtdrvGattServiceUuidType_FitnessMachine               = 0x1826,    ///< Fitness Machine
    BtdrvGattServiceUuidType_MeshProvisioning             = 0x1827,    ///< Mesh Provisioning
    BtdrvGattServiceUuidType_MeshProxy                    = 0x1828,    ///< Mesh Proxy
    BtdrvGattServiceUuidType_ReconnectionConfiguration    = 0x1829,    ///< Reconnection Configuration
    BtdrvGattServiceUuidType_InsulinDelivery              = 0x183A,    ///< Insulin Delivery
    BtdrvGattServiceUuidType_BinarySensor                 = 0x183B,    ///< Binary Sensor
    BtdrvGattServiceUuidType_EmergencyConfiguration       = 0x183C,    ///< Emergency Configuration
    BtdrvGattServiceUuidType_AuthorizationControl         = 0x183D,    ///< Authorization Control
    BtdrvGattServiceUuidType_PhysicalActivityMonitor      = 0x183E,    ///< Physical Activity Monitor
    BtdrvGattServiceUuidType_ElapsedTime                  = 0x183F,    ///< Elapsed Time
    BtdrvGattServiceUuidType_GenericHealthSensor          = 0x1840,    ///< Generic Health Sensor
    BtdrvGattServiceUuidType_AudioInputControl            = 0x1843,    ///< Audio Input Control
    BtdrvGattServiceUuidType_VolumeControl                = 0x1844,    ///< Volume Control
    BtdrvGattServiceUuidType_VolumeOffsetControl          = 0x1845,    ///< Volume Offset Control
    BtdrvGattServiceUuidType_CoordinatedSetIdentification = 0x1846,    ///< Coordinated Set Identification
    BtdrvGattServiceUuidType_DeviceTime                   = 0x1847,    ///< Device Time
    BtdrvGattServiceUuidType_MediaControl                 = 0x1848,    ///< Media Control
    BtdrvGattServiceUuidType_GenericMediaControl          = 0x1849,    ///< Generic Media Control
    BtdrvGattServiceUuidType_ConstantToneExtension        = 0x184A,    ///< Constant Tone Extension
    BtdrvGattServiceUuidType_TelephoneBearer              = 0x184B,    ///< Telephone Bearer
    BtdrvGattServiceUuidType_GenericTelephoneBearer       = 0x184C,    ///< Generic Telephone Bearer
    BtdrvGattServiceUuidType_MicrophoneControl            = 0x184D,    ///< Microphone Control
    BtdrvGattServiceUuidType_AudioStreamControl           = 0x184E,    ///< Audio Stream Control
    BtdrvGattServiceUuidType_BroadcastAudioScan           = 0x184F,    ///< Broadcast Audio Scan
    BtdrvGattServiceUuidType_PublishedAudioCapabilities   = 0x1850,    ///< Published Audio Capabilities
    BtdrvGattServiceUuidType_BasicAudioAnnouncement       = 0x1851,    ///< Basic Audio Announcement
    BtdrvGattServiceUuidType_BroadcastAudioAnnouncement   = 0x1852,    ///< Broadcast Audio Announcement
    BtdrvGattServiceUuidType_CommonAudio                  = 0x1853,    ///< Common Audio
    BtdrvGattServiceUuidType_HearingAccess                = 0x1854,    ///< Hearing Access
    BtdrvGattServiceUuidType_TelephonyAndMediaAudio       = 0x1855,    ///< Telephony and Media Audio
    BtdrvGattServiceUuidType_PublicBroadcastAnnouncement  = 0x1856,    ///< Public Broadcast Announcement
    BtdrvGattServiceUuidType_ElectronicShelfLabel         = 0x1857,    ///< Electronic Shelf Label
} BtdrvGattServiceUuidType;

/// GattCharacteristicUuidType
typedef enum {
    BtdrvGattCharacteristicUuidType_DeviceName                                           = 0x2A00,    ///< Device Name
    BtdrvGattCharacteristicUuidType_Appearance                                           = 0x2A01,    ///< Appearance
    BtdrvGattCharacteristicUuidType_PeripheralPrivacyFlag                                = 0x2A02,    ///< Peripheral Privacy Flag
    BtdrvGattCharacteristicUuidType_ReconnectionAddress                                  = 0x2A03,    ///< Reconnection Address
    BtdrvGattCharacteristicUuidType_PeripheralPreferredConnectionParameters              = 0x2A04,    ///< Peripheral Preferred Connection Parameters
    BtdrvGattCharacteristicUuidType_ServiceChanged                                       = 0x2A05,    ///< Service Changed
    BtdrvGattCharacteristicUuidType_AlertLevel                                           = 0x2A06,    ///< Alert Level
    BtdrvGattCharacteristicUuidType_TxPowerLevel                                         = 0x2A07,    ///< Tx Power Level
    BtdrvGattCharacteristicUuidType_DateTime                                             = 0x2A08,    ///< Date Time
    BtdrvGattCharacteristicUuidType_DayOfWeek                                            = 0x2A09,    ///< Day of Week
    BtdrvGattCharacteristicUuidType_DayDateTime                                          = 0x2A0A,    ///< Day Date Time
    BtdrvGattCharacteristicUuidType_ExactTime256                                         = 0x2A0C,    ///< Exact Time 256
    BtdrvGattCharacteristicUuidType_DstOffset                                            = 0x2A0D,    ///< DST Offset
    BtdrvGattCharacteristicUuidType_TimeZone                                             = 0x2A0E,    ///< Time Zone
    BtdrvGattCharacteristicUuidType_LocalTimeInformation                                 = 0x2A0F,    ///< Local Time Information
    BtdrvGattCharacteristicUuidType_TimeWithDst                                          = 0x2A11,    ///< Time with DST
    BtdrvGattCharacteristicUuidType_TimeAccuracy                                         = 0x2A12,    ///< Time Accuracy
    BtdrvGattCharacteristicUuidType_TimeSource                                           = 0x2A13,    ///< Time Source
    BtdrvGattCharacteristicUuidType_ReferenceTimeInformation                             = 0x2A14,    ///< Reference Time Information
    BtdrvGattCharacteristicUuidType_TimeUpdateControlPoint                               = 0x2A16,    ///< Time Update Control Point
    BtdrvGattCharacteristicUuidType_TimeUpdateState                                      = 0x2A17,    ///< Time Update State
    BtdrvGattCharacteristicUuidType_GlucoseMeasurement                                   = 0x2A18,    ///< Glucose Measurement
    BtdrvGattCharacteristicUuidType_BatteryLevel                                         = 0x2A19,    ///< Battery Level
    BtdrvGattCharacteristicUuidType_TemperatureMeasurement                               = 0x2A1C,    ///< Temperature Measurement
    BtdrvGattCharacteristicUuidType_TemperatureType                                      = 0x2A1D,    ///< Temperature Type
    BtdrvGattCharacteristicUuidType_IntermediateTemperature                              = 0x2A1E,    ///< Intermediate Temperature
    BtdrvGattCharacteristicUuidType_MeasurementInterval                                  = 0x2A21,    ///< Measurement Interval
    BtdrvGattCharacteristicUuidType_BootKeyboardInputReport                              = 0x2A22,    ///< Boot Keyboard Input Report
    BtdrvGattCharacteristicUuidType_SystemId                                             = 0x2A23,    ///< System ID
    BtdrvGattCharacteristicUuidType_ModelNumberString                                    = 0x2A24,    ///< Model Number String
    BtdrvGattCharacteristicUuidType_SerialNumberString                                   = 0x2A25,    ///< Serial Number String
    BtdrvGattCharacteristicUuidType_FirmwareRevisionString                               = 0x2A26,    ///< Firmware Revision String
    BtdrvGattCharacteristicUuidType_HardwareRevisionString                               = 0x2A27,    ///< Hardware Revision String
    BtdrvGattCharacteristicUuidType_SoftwareRevisionString                               = 0x2A28,    ///< Software Revision String
    BtdrvGattCharacteristicUuidType_ManufacturerNameString                               = 0x2A29,    ///< Manufacturer Name String
    BtdrvGattCharacteristicUuidType_IeeeRegulatoryCertificationDataList                  = 0x2A2A,    ///< IEEE 11073-20601 Regulatory Certification Data List
    BtdrvGattCharacteristicUuidType_CurrentTime                                          = 0x2A2B,    ///< Current Time
    BtdrvGattCharacteristicUuidType_MagneticDeclination                                  = 0x2A2C,    ///< Magnetic Declination
    BtdrvGattCharacteristicUuidType_ScanRefresh                                          = 0x2A31,    ///< Scan Refresh
    BtdrvGattCharacteristicUuidType_BootKeyboardOutputReport                             = 0x2A32,    ///< Boot Keyboard Output Report
    BtdrvGattCharacteristicUuidType_BootMouseInputReport                                 = 0x2A33,    ///< Boot Mouse Input Report
    BtdrvGattCharacteristicUuidType_GlucoseMeasurementContext                            = 0x2A34,    ///< Glucose Measurement Context
    BtdrvGattCharacteristicUuidType_BloodPressureMeasurement                             = 0x2A35,    ///< Blood Pressure Measurement
    BtdrvGattCharacteristicUuidType_IntermediateCuffPressure                             = 0x2A36,    ///< Intermediate Cuff Pressure
    BtdrvGattCharacteristicUuidType_HeartRateMeasurement                                 = 0x2A37,    ///< Heart Rate Measurement
    BtdrvGattCharacteristicUuidType_BodySensorLocation                                   = 0x2A38,    ///< Body Sensor Location
    BtdrvGattCharacteristicUuidType_HeartRateControlPoint                                = 0x2A39,    ///< Heart Rate Control Point
    BtdrvGattCharacteristicUuidType_AlertStatus                                          = 0x2A3F,    ///< Alert Status
    BtdrvGattCharacteristicUuidType_RingerControlPoint                                   = 0x2A40,    ///< Ringer Control Point
    BtdrvGattCharacteristicUuidType_RingerSetting                                        = 0x2A41,    ///< Ringer Setting
    BtdrvGattCharacteristicUuidType_AlertCategoryIdBitMask                               = 0x2A42,    ///< Alert Category ID Bit Mask
    BtdrvGattCharacteristicUuidType_AlertCategoryId                                      = 0x2A43,    ///< Alert Category ID
    BtdrvGattCharacteristicUuidType_AlertNotificationControlPoint                        = 0x2A44,    ///< Alert Notification Control Point
    BtdrvGattCharacteristicUuidType_UnreadAlertStatus                                    = 0x2A45,    ///< Unread Alert Status
    BtdrvGattCharacteristicUuidType_NewAlert                                             = 0x2A46,    ///< New Alert
    BtdrvGattCharacteristicUuidType_SupportedNewAlertCategory                            = 0x2A47,    ///< Supported New Alert Category
    BtdrvGattCharacteristicUuidType_SupportedUnreadAlertCategory                         = 0x2A48,    ///< Supported Unread Alert Category
    BtdrvGattCharacteristicUuidType_BloodPressureFeature                                 = 0x2A49,    ///< Blood Pressure Feature
    BtdrvGattCharacteristicUuidType_HidInformation                                       = 0x2A4A,    ///< HID Information
    BtdrvGattCharacteristicUuidType_ReportMap                                            = 0x2A4B,    ///< Report Map
    BtdrvGattCharacteristicUuidType_HidControlPoint                                      = 0x2A4C,    ///< HID Control Point
    BtdrvGattCharacteristicUuidType_Report                                               = 0x2A4D,    ///< Report
    BtdrvGattCharacteristicUuidType_ProtocolMode                                         = 0x2A4E,    ///< Protocol Mode
    BtdrvGattCharacteristicUuidType_ScanIntervalWindow                                   = 0x2A4F,    ///< Scan Interval Window
    BtdrvGattCharacteristicUuidType_PnpId                                                = 0x2A50,    ///< PnP ID
    BtdrvGattCharacteristicUuidType_GlucoseFeature                                       = 0x2A51,    ///< Glucose Feature
    BtdrvGattCharacteristicUuidType_RecordAccessControlPoint                             = 0x2A52,    ///< Record Access Control Point
    BtdrvGattCharacteristicUuidType_RscMeasurement                                       = 0x2A53,    ///< RSC Measurement
    BtdrvGattCharacteristicUuidType_RscFeature                                           = 0x2A54,    ///< RSC Feature
    BtdrvGattCharacteristicUuidType_ScControlPoint                                       = 0x2A55,    ///< SC Control Point
    BtdrvGattCharacteristicUuidType_Aggregate                                            = 0x2A5A,    ///< Aggregate
    BtdrvGattCharacteristicUuidType_CscMeasurement                                       = 0x2A5B,    ///< CSC Measurement
    BtdrvGattCharacteristicUuidType_CscFeature                                           = 0x2A5C,    ///< CSC Feature
    BtdrvGattCharacteristicUuidType_SensorLocation                                       = 0x2A5D,    ///< Sensor Location
    BtdrvGattCharacteristicUuidType_PlxSpotCheckMeasurement                              = 0x2A5E,    ///< PLX Spot-Check Measurement
    BtdrvGattCharacteristicUuidType_PlxContinuousMeasurement                             = 0x2A5F,    ///< PLX Continuous Measurement
    BtdrvGattCharacteristicUuidType_PlxFeatures                                          = 0x2A60,    ///< PLX Features
    BtdrvGattCharacteristicUuidType_CyclingPowerMeasurement                              = 0x2A63,    ///< Cycling Power Measurement
    BtdrvGattCharacteristicUuidType_CyclingPowerVector                                   = 0x2A64,    ///< Cycling Power Vector
    BtdrvGattCharacteristicUuidType_CyclingPowerFeature                                  = 0x2A65,    ///< Cycling Power Feature
    BtdrvGattCharacteristicUuidType_CyclingPowerControlPoint                             = 0x2A66,    ///< Cycling Power Control Point
    BtdrvGattCharacteristicUuidType_LocationAndSpeed                                     = 0x2A67,    ///< Location and Speed
    BtdrvGattCharacteristicUuidType_Navigation                                           = 0x2A68,    ///< Navigation
    BtdrvGattCharacteristicUuidType_PositionQuality                                      = 0x2A69,    ///< Position Quality
    BtdrvGattCharacteristicUuidType_LnFeature                                            = 0x2A6A,    ///< LN Feature
    BtdrvGattCharacteristicUuidType_LnControlPoint                                       = 0x2A6B,    ///< LN Control Point
    BtdrvGattCharacteristicUuidType_Elevation                                            = 0x2A6C,    ///< Elevation
    BtdrvGattCharacteristicUuidType_Pressure                                             = 0x2A6D,    ///< Pressure
    BtdrvGattCharacteristicUuidType_Temperature                                          = 0x2A6E,    ///< Temperature
    BtdrvGattCharacteristicUuidType_Humidity                                             = 0x2A6F,    ///< Humidity
    BtdrvGattCharacteristicUuidType_TrueWindSpeed                                        = 0x2A70,    ///< True Wind Speed
    BtdrvGattCharacteristicUuidType_TrueWindDirection                                    = 0x2A71,    ///< True Wind Direction
    BtdrvGattCharacteristicUuidType_ApparentWindSpeed                                    = 0x2A72,    ///< Apparent Wind Speed
    BtdrvGattCharacteristicUuidType_ApparentWindDirection                                = 0x2A73,    ///< Apparent Wind Direction
    BtdrvGattCharacteristicUuidType_GustFactor                                           = 0x2A74,    ///< Gust Factor
    BtdrvGattCharacteristicUuidType_PollenConcentration                                  = 0x2A75,    ///< Pollen Concentration
    BtdrvGattCharacteristicUuidType_UvIndex                                              = 0x2A76,    ///< UV Index
    BtdrvGattCharacteristicUuidType_Irradiance                                           = 0x2A77,    ///< Irradiance
    BtdrvGattCharacteristicUuidType_Rainfall                                             = 0x2A78,    ///< Rainfall
    BtdrvGattCharacteristicUuidType_WindChill                                            = 0x2A79,    ///< Wind Chill
    BtdrvGattCharacteristicUuidType_HeatIndex                                            = 0x2A7A,    ///< Heat Index
    BtdrvGattCharacteristicUuidType_DewPoint                                             = 0x2A7B,    ///< Dew Point
    BtdrvGattCharacteristicUuidType_DescriptorValueChanged                               = 0x2A7D,    ///< Descriptor Value Changed
    BtdrvGattCharacteristicUuidType_AerobicHeartRateLowerLimit                           = 0x2A7E,    ///< Aerobic Heart Rate Lower Limit
    BtdrvGattCharacteristicUuidType_AerobicThreshold                                     = 0x2A7F,    ///< Aerobic Threshold
    BtdrvGattCharacteristicUuidType_Age                                                  = 0x2A80,    ///< Age
    BtdrvGattCharacteristicUuidType_AnaerobicHeartRateLowerLimit                         = 0x2A81,    ///< Anaerobic Heart Rate Lower Limit
    BtdrvGattCharacteristicUuidType_AnaerobicHeartRateUpperLimit                         = 0x2A82,    ///< Anaerobic Heart Rate Upper Limit
    BtdrvGattCharacteristicUuidType_AnaerobicThreshold                                   = 0x2A83,    ///< Anaerobic Threshold
    BtdrvGattCharacteristicUuidType_AerobicHeartRateUpperLimit                           = 0x2A84,    ///< Aerobic Heart Rate Upper Limit
    BtdrvGattCharacteristicUuidType_DateOfBirth                                          = 0x2A85,    ///< Date of Birth
    BtdrvGattCharacteristicUuidType_DateOfThresholdAssessment                            = 0x2A86,    ///< Date of Threshold Assessment
    BtdrvGattCharacteristicUuidType_EmailAddress                                         = 0x2A87,    ///< Email Address
    BtdrvGattCharacteristicUuidType_FatBurnHeartRateLowerLimit                           = 0x2A88,    ///< Fat Burn Heart Rate Lower Limit
    BtdrvGattCharacteristicUuidType_FatBurnHeartRateUpperLimit                           = 0x2A89,    ///< Fat Burn Heart Rate Upper Limit
    BtdrvGattCharacteristicUuidType_FirstName                                            = 0x2A8A,    ///< First Name
    BtdrvGattCharacteristicUuidType_FiveZoneHeartRateLimits                              = 0x2A8B,    ///< Five Zone Heart Rate Limits
    BtdrvGattCharacteristicUuidType_Gender                                               = 0x2A8C,    ///< Gender
    BtdrvGattCharacteristicUuidType_HeartRateMax                                         = 0x2A8D,    ///< Heart Rate Max
    BtdrvGattCharacteristicUuidType_Height                                               = 0x2A8E,    ///< Height
    BtdrvGattCharacteristicUuidType_HipCircumference                                     = 0x2A8F,    ///< Hip Circumference
    BtdrvGattCharacteristicUuidType_LastName                                             = 0x2A90,    ///< Last Name
    BtdrvGattCharacteristicUuidType_MaximumRecommendedHeartRate                          = 0x2A91,    ///< Maximum Recommended Heart Rate
    BtdrvGattCharacteristicUuidType_RestingHeartRate                                     = 0x2A92,    ///< Resting Heart Rate
    BtdrvGattCharacteristicUuidType_SportTypeForAerobicAndAnaerobicThresholds            = 0x2A93,    ///< Sport Type for Aerobic and Anaerobic Thresholds
    BtdrvGattCharacteristicUuidType_ThreeZoneHeartRateLimits                             = 0x2A94,    ///< Three Zone Heart Rate Limits
    BtdrvGattCharacteristicUuidType_TwoZoneHeartRateLimits                               = 0x2A95,    ///< Two Zone Heart Rate Limits
    BtdrvGattCharacteristicUuidType_Vo2Max                                               = 0x2A96,    ///< VO2 Max
    BtdrvGattCharacteristicUuidType_WaistCircumference                                   = 0x2A97,    ///< Waist Circumference
    BtdrvGattCharacteristicUuidType_Weight                                               = 0x2A98,    ///< Weight
    BtdrvGattCharacteristicUuidType_DatabaseChangeIncrement                              = 0x2A99,    ///< Database Change Increment
    BtdrvGattCharacteristicUuidType_UserIndex                                            = 0x2A9A,    ///< User Index
    BtdrvGattCharacteristicUuidType_BodyCompositionFeature                               = 0x2A9B,    ///< Body Composition Feature
    BtdrvGattCharacteristicUuidType_BodyCompositionMeasurement                           = 0x2A9C,    ///< Body Composition Measurement
    BtdrvGattCharacteristicUuidType_WeightMeasurement                                    = 0x2A9D,    ///< Weight Measurement
    BtdrvGattCharacteristicUuidType_WeightScaleFeature                                   = 0x2A9E,    ///< Weight Scale Feature
    BtdrvGattCharacteristicUuidType_UserControlPoint                                     = 0x2A9F,    ///< User Control Point
    BtdrvGattCharacteristicUuidType_MagneticFluxDensity2D                                = 0x2AA0,    ///< Magnetic Flux Density - 2D
    BtdrvGattCharacteristicUuidType_MagneticFluxDensity3D                                = 0x2AA1,    ///< Magnetic Flux Density - 3D
    BtdrvGattCharacteristicUuidType_Language                                             = 0x2AA2,    ///< Language
    BtdrvGattCharacteristicUuidType_BarometricPressureTrend                              = 0x2AA3,    ///< Barometric Pressure Trend
    BtdrvGattCharacteristicUuidType_BondManagementControlPoint                           = 0x2AA4,    ///< Bond Management Control Point
    BtdrvGattCharacteristicUuidType_BondManagementFeature                                = 0x2AA5,    ///< Bond Management Feature
    BtdrvGattCharacteristicUuidType_CentralAddressResolution                             = 0x2AA6,    ///< Central Address Resolution
    BtdrvGattCharacteristicUuidType_CgmMeasurement                                       = 0x2AA7,    ///< CGM Measurement
    BtdrvGattCharacteristicUuidType_CgmFeature                                           = 0x2AA8,    ///< CGM Feature
    BtdrvGattCharacteristicUuidType_CgmStatus                                            = 0x2AA9,    ///< CGM Status
    BtdrvGattCharacteristicUuidType_CgmSessionStartTime                                  = 0x2AAA,    ///< CGM Session Start Time
    BtdrvGattCharacteristicUuidType_CgmSessionRunTime                                    = 0x2AAB,    ///< CGM Session Run Time
    BtdrvGattCharacteristicUuidType_CgmSpecificOpsControlPoint                           = 0x2AAC,    ///< CGM Specific Ops Control Point
    BtdrvGattCharacteristicUuidType_IndoorPositioningConfiguration                       = 0x2AAD,    ///< Indoor Positioning Configuration
    BtdrvGattCharacteristicUuidType_Latitude                                             = 0x2AAE,    ///< Latitude
    BtdrvGattCharacteristicUuidType_Longitude                                            = 0x2AAF,    ///< Longitude
    BtdrvGattCharacteristicUuidType_LocalNorthCoordinate                                 = 0x2AB0,    ///< Local North Coordinate
    BtdrvGattCharacteristicUuidType_LocalEastCoordinate                                  = 0x2AB1,    ///< Local East Coordinate
    BtdrvGattCharacteristicUuidType_FloorNumber                                          = 0x2AB2,    ///< Floor Number
    BtdrvGattCharacteristicUuidType_Altitude                                             = 0x2AB3,    ///< Altitude
    BtdrvGattCharacteristicUuidType_Uncertainty                                          = 0x2AB4,    ///< Uncertainty
    BtdrvGattCharacteristicUuidType_LocationName                                         = 0x2AB5,    ///< Location Name
    BtdrvGattCharacteristicUuidType_Uri                                                  = 0x2AB6,    ///< URI
    BtdrvGattCharacteristicUuidType_HttpHeaders                                          = 0x2AB7,    ///< HTTP Headers
    BtdrvGattCharacteristicUuidType_HttpStatusCode                                       = 0x2AB8,    ///< HTTP Status Code
    BtdrvGattCharacteristicUuidType_HttpEntityBody                                       = 0x2AB9,    ///< HTTP Entity Body
    BtdrvGattCharacteristicUuidType_HttpControlPoint                                     = 0x2ABA,    ///< HTTP Control Point
    BtdrvGattCharacteristicUuidType_HttpsSecurity                                        = 0x2ABB,    ///< HTTPS Security
    BtdrvGattCharacteristicUuidType_TdsControlPoint                                      = 0x2ABC,    ///< TDS Control Point
    BtdrvGattCharacteristicUuidType_OtsFeature                                           = 0x2ABD,    ///< OTS Feature
    BtdrvGattCharacteristicUuidType_ObjectName                                           = 0x2ABE,    ///< Object Name
    BtdrvGattCharacteristicUuidType_ObjectType                                           = 0x2ABF,    ///< Object Type
    BtdrvGattCharacteristicUuidType_ObjectSize                                           = 0x2AC0,    ///< Object Size
    BtdrvGattCharacteristicUuidType_ObjectFirstCreated                                   = 0x2AC1,    ///< Object First-Created
    BtdrvGattCharacteristicUuidType_ObjectLastModified                                   = 0x2AC2,    ///< Object Last-Modified
    BtdrvGattCharacteristicUuidType_ObjectId                                             = 0x2AC3,    ///< Object ID
    BtdrvGattCharacteristicUuidType_ObjectProperties                                     = 0x2AC4,    ///< Object Properties
    BtdrvGattCharacteristicUuidType_ObjectActionControlPoint                             = 0x2AC5,    ///< Object Action Control Point
    BtdrvGattCharacteristicUuidType_ObjectListControlPoint                               = 0x2AC6,    ///< Object List Control Point
    BtdrvGattCharacteristicUuidType_ObjectListFilter                                     = 0x2AC7,    ///< Object List Filter
    BtdrvGattCharacteristicUuidType_ObjectChanged                                        = 0x2AC8,    ///< Object Changed
    BtdrvGattCharacteristicUuidType_ResolvablePrivateAddressOnly                         = 0x2AC9,    ///< Resolvable Private Address Only
    BtdrvGattCharacteristicUuidType_FitnessMachineFeature                                = 0x2ACC,    ///< Fitness Machine Feature
    BtdrvGattCharacteristicUuidType_TreadmillData                                        = 0x2ACD,    ///< Treadmill Data
    BtdrvGattCharacteristicUuidType_CrossTrainerData                                     = 0x2ACE,    ///< Cross Trainer Data
    BtdrvGattCharacteristicUuidType_StepClimberData                                      = 0x2ACF,    ///< Step Climber Data
    BtdrvGattCharacteristicUuidType_StairClimberData                                     = 0x2AD0,    ///< Stair Climber Data
    BtdrvGattCharacteristicUuidType_RowerData                                            = 0x2AD1,    ///< Rower Data
    BtdrvGattCharacteristicUuidType_IndoorBikeData                                       = 0x2AD2,    ///< Indoor Bike Data
    BtdrvGattCharacteristicUuidType_TrainingStatus                                       = 0x2AD3,    ///< Training Status
    BtdrvGattCharacteristicUuidType_SupportedSpeedRange                                  = 0x2AD4,    ///< Supported Speed Range
    BtdrvGattCharacteristicUuidType_SupportedInclinationRange                            = 0x2AD5,    ///< Supported Inclination Range
    BtdrvGattCharacteristicUuidType_SupportedResistanceLevelRange                        = 0x2AD6,    ///< Supported Resistance Level Range
    BtdrvGattCharacteristicUuidType_SupportedHeartRateRange                              = 0x2AD7,    ///< Supported Heart Rate Range
    BtdrvGattCharacteristicUuidType_SupportedPowerRange                                  = 0x2AD8,    ///< Supported Power Range
    BtdrvGattCharacteristicUuidType_FitnessMachineControlPoint                           = 0x2AD9,    ///< Fitness Machine Control Point
    BtdrvGattCharacteristicUuidType_FitnessMachineStatus                                 = 0x2ADA,    ///< Fitness Machine Status
    BtdrvGattCharacteristicUuidType_MeshProvisioningDataIn                               = 0x2ADB,    ///< Mesh Provisioning Data In
    BtdrvGattCharacteristicUuidType_MeshProvisioningDataOut                              = 0x2ADC,    ///< Mesh Provisioning Data Out
    BtdrvGattCharacteristicUuidType_MeshProxyDataIn                                      = 0x2ADD,    ///< Mesh Proxy Data In
    BtdrvGattCharacteristicUuidType_MeshProxyDataOut                                     = 0x2ADE,    ///< Mesh Proxy Data Out
    BtdrvGattCharacteristicUuidType_AverageCurrent                                       = 0x2AE0,    ///< Average Current
    BtdrvGattCharacteristicUuidType_AverageVoltage                                       = 0x2AE1,    ///< Average Voltage
    BtdrvGattCharacteristicUuidType_Boolean                                              = 0x2AE2,    ///< Boolean
    BtdrvGattCharacteristicUuidType_ChromaticDistanceFromPlanckian                       = 0x2AE3,    ///< Chromatic Distance from Planckian
    BtdrvGattCharacteristicUuidType_ChromaticityCoordinates                              = 0x2AE4,    ///< Chromaticity Coordinates
    BtdrvGattCharacteristicUuidType_ChromaticityInCctAndDuvValues                        = 0x2AE5,    ///< Chromaticity in CCT and Duv Values
    BtdrvGattCharacteristicUuidType_ChromaticityTolerance                                = 0x2AE6,    ///< Chromaticity Tolerance
    BtdrvGattCharacteristicUuidType_CieColorRenderingIndex                               = 0x2AE7,    ///< CIE 13.3-1995 Color Rendering Index
    BtdrvGattCharacteristicUuidType_Coefficient                                          = 0x2AE8,    ///< Coefficient
    BtdrvGattCharacteristicUuidType_CorrelatedColorTemperature                           = 0x2AE9,    ///< Correlated Color Temperature
    BtdrvGattCharacteristicUuidType_Count16                                              = 0x2AEA,    ///< Count 16
    BtdrvGattCharacteristicUuidType_Count24                                              = 0x2AEB,    ///< Count 24
    BtdrvGattCharacteristicUuidType_CountryCode                                          = 0x2AEC,    ///< Country Code
    BtdrvGattCharacteristicUuidType_DateUtc                                              = 0x2AED,    ///< Date UTC
    BtdrvGattCharacteristicUuidType_ElectricCurrent                                      = 0x2AEE,    ///< Electric Current
    BtdrvGattCharacteristicUuidType_ElectricCurrentRange                                 = 0x2AEF,    ///< Electric Current Range
    BtdrvGattCharacteristicUuidType_ElectricCurrentSpecification                         = 0x2AF0,    ///< Electric Current Specification
    BtdrvGattCharacteristicUuidType_ElectricCurrentStatistics                            = 0x2AF1,    ///< Electric Current Statistics
    BtdrvGattCharacteristicUuidType_Energy                                               = 0x2AF2,    ///< Energy
    BtdrvGattCharacteristicUuidType_EnergyInAPeriodOfDay                                 = 0x2AF3,    ///< Energy in a Period of Day
    BtdrvGattCharacteristicUuidType_EventStatistics                                      = 0x2AF4,    ///< Event Statistics
    BtdrvGattCharacteristicUuidType_FixedString16                                        = 0x2AF5,    ///< Fixed String 16
    BtdrvGattCharacteristicUuidType_FixedString24                                        = 0x2AF6,    ///< Fixed String 24
    BtdrvGattCharacteristicUuidType_FixedString36                                        = 0x2AF7,    ///< Fixed String 36
    BtdrvGattCharacteristicUuidType_FixedString8                                         = 0x2AF8,    ///< Fixed String 8
    BtdrvGattCharacteristicUuidType_GenericLevel                                         = 0x2AF9,    ///< Generic Level
    BtdrvGattCharacteristicUuidType_GlobalTradeItemNumber                                = 0x2AFA,    ///< Global Trade Item Number
    BtdrvGattCharacteristicUuidType_Illuminance                                          = 0x2AFB,    ///< Illuminance
    BtdrvGattCharacteristicUuidType_LuminousEfficacy                                     = 0x2AFC,    ///< Luminous Efficacy
    BtdrvGattCharacteristicUuidType_LuminousEnergy                                       = 0x2AFD,    ///< Luminous Energy
    BtdrvGattCharacteristicUuidType_LuminousExposure                                     = 0x2AFE,    ///< Luminous Exposure
    BtdrvGattCharacteristicUuidType_LuminousFlux                                         = 0x2AFF,    ///< Luminous Flux
    BtdrvGattCharacteristicUuidType_LuminousFluxRange                                    = 0x2B00,    ///< Luminous Flux Range
    BtdrvGattCharacteristicUuidType_LuminousIntensity                                    = 0x2B01,    ///< Luminous Intensity
    BtdrvGattCharacteristicUuidType_MassFlow                                             = 0x2B02,    ///< Mass Flow
    BtdrvGattCharacteristicUuidType_PerceivedLightness                                   = 0x2B03,    ///< Perceived Lightness
    BtdrvGattCharacteristicUuidType_Percentage8                                          = 0x2B04,    ///< Percentage 8
    BtdrvGattCharacteristicUuidType_Power                                                = 0x2B05,    ///< Power
    BtdrvGattCharacteristicUuidType_PowerSpecification                                   = 0x2B06,    ///< Power Specification
    BtdrvGattCharacteristicUuidType_RelativeRuntimeInACurrentRange                       = 0x2B07,    ///< Relative Runtime in a Current Range
    BtdrvGattCharacteristicUuidType_RelativeRuntimeInAGenericLevelRange                  = 0x2B08,    ///< Relative Runtime in a Generic Level Range
    BtdrvGattCharacteristicUuidType_RelativeValueInAVoltageRange                         = 0x2B09,    ///< Relative Value in a Voltage Range
    BtdrvGattCharacteristicUuidType_RelativeValueInAnIlluminanceRange                    = 0x2B0A,    ///< Relative Value in an Illuminance Range
    BtdrvGattCharacteristicUuidType_RelativeValueInAPeriodOfDay                          = 0x2B0B,    ///< Relative Value in a Period of Day
    BtdrvGattCharacteristicUuidType_RelativeValueInATemperatureRange                     = 0x2B0C,    ///< Relative Value in a Temperature Range
    BtdrvGattCharacteristicUuidType_Temperature8                                         = 0x2B0D,    ///< Temperature 8
    BtdrvGattCharacteristicUuidType_Temperature8InAPeriodOfDay                           = 0x2B0E,    ///< Temperature 8 in a Period of Day
    BtdrvGattCharacteristicUuidType_Temperature8Statistics                               = 0x2B0F,    ///< Temperature 8 Statistics
    BtdrvGattCharacteristicUuidType_TemperatureRange                                     = 0x2B10,    ///< Temperature Range
    BtdrvGattCharacteristicUuidType_TemperatureStatistics                                = 0x2B11,    ///< Temperature Statistics
    BtdrvGattCharacteristicUuidType_TimeDecihour8                                        = 0x2B12,    ///< Time Decihour 8
    BtdrvGattCharacteristicUuidType_TimeExponential8                                     = 0x2B13,    ///< Time Exponential 8
    BtdrvGattCharacteristicUuidType_TimeHour24                                           = 0x2B14,    ///< Time Hour 24
    BtdrvGattCharacteristicUuidType_TimeMillisecond24                                    = 0x2B15,    ///< Time Millisecond 24
    BtdrvGattCharacteristicUuidType_TimeSecond16                                         = 0x2B16,    ///< Time Second 16
    BtdrvGattCharacteristicUuidType_TimeSecond8                                          = 0x2B17,    ///< Time Second 8
    BtdrvGattCharacteristicUuidType_Voltage                                              = 0x2B18,    ///< Voltage
    BtdrvGattCharacteristicUuidType_VoltageSpecification                                 = 0x2B19,    ///< Voltage Specification
    BtdrvGattCharacteristicUuidType_VoltageStatistics                                    = 0x2B1A,    ///< Voltage Statistics
    BtdrvGattCharacteristicUuidType_VolumeFlow                                           = 0x2B1B,    ///< Volume Flow
    BtdrvGattCharacteristicUuidType_ChromaticityCoordinate                               = 0x2B1C,    ///< Chromaticity Coordinate
    BtdrvGattCharacteristicUuidType_RcFeature                                            = 0x2B1D,    ///< RC Feature
    BtdrvGattCharacteristicUuidType_RcSettings                                           = 0x2B1E,    ///< RC Settings
    BtdrvGattCharacteristicUuidType_ReconnectionConfigurationControlPoint                = 0x2B1F,    ///< Reconnection Configuration Control Point
    BtdrvGattCharacteristicUuidType_IddStatusChanged                                     = 0x2B20,    ///< IDD Status Changed
    BtdrvGattCharacteristicUuidType_IddStatus                                            = 0x2B21,    ///< IDD Status
    BtdrvGattCharacteristicUuidType_IddAnnunciationStatus                                = 0x2B22,    ///< IDD Annunciation Status
    BtdrvGattCharacteristicUuidType_IddFeatures                                          = 0x2B23,    ///< IDD Features
    BtdrvGattCharacteristicUuidType_IddStatusReaderControlPoint                          = 0x2B24,    ///< IDD Status Reader Control Point
    BtdrvGattCharacteristicUuidType_IddCommandControlPoint                               = 0x2B25,    ///< IDD Command Control Point
    BtdrvGattCharacteristicUuidType_IddCommandData                                       = 0x2B26,    ///< IDD Command Data
    BtdrvGattCharacteristicUuidType_IddRecordAccessControlPoint                          = 0x2B27,    ///< IDD Record Access Control Point
    BtdrvGattCharacteristicUuidType_IddHistoryData                                       = 0x2B28,    ///< IDD History Data
    BtdrvGattCharacteristicUuidType_ClientSupportedFeatures                              = 0x2B29,    ///< Client Supported Features
    BtdrvGattCharacteristicUuidType_DatabaseHash                                         = 0x2B2A,    ///< Database Hash
    BtdrvGattCharacteristicUuidType_BssControlPoint                                      = 0x2B2B,    ///< BSS Control Point
    BtdrvGattCharacteristicUuidType_BssResponse                                          = 0x2B2C,    ///< BSS Response
    BtdrvGattCharacteristicUuidType_EmergencyId                                          = 0x2B2D,    ///< Emergency ID
    BtdrvGattCharacteristicUuidType_EmergencyText                                        = 0x2B2E,    ///< Emergency Text
    BtdrvGattCharacteristicUuidType_AcsStatus                                            = 0x2B2F,    ///< ACS Status
    BtdrvGattCharacteristicUuidType_AcsDataIn                                            = 0x2B30,    ///< ACS Data In
    BtdrvGattCharacteristicUuidType_AcsDataOutNotify                                     = 0x2B31,    ///< ACS Data Out Notify
    BtdrvGattCharacteristicUuidType_AcsDataOutIndicate                                   = 0x2B32,    ///< ACS Data Out Indicate
    BtdrvGattCharacteristicUuidType_AcsControlPoint                                      = 0x2B33,    ///< ACS Control Point
    BtdrvGattCharacteristicUuidType_EnhancedBloodPressureMeasurement                     = 0x2B34,    ///< Enhanced Blood Pressure Measurement
    BtdrvGattCharacteristicUuidType_EnhancedIntermediateCuffPressure                     = 0x2B35,    ///< Enhanced Intermediate Cuff Pressure
    BtdrvGattCharacteristicUuidType_BloodPressureRecord                                  = 0x2B36,    ///< Blood Pressure Record
    BtdrvGattCharacteristicUuidType_RegisteredUser                                       = 0x2B37,    ///< Registered User
    BtdrvGattCharacteristicUuidType_BrEdrHandoverData                                    = 0x2B38,    ///< BR-EDR Handover Data
    BtdrvGattCharacteristicUuidType_BluetoothSigData                                     = 0x2B39,    ///< Bluetooth SIG Data
    BtdrvGattCharacteristicUuidType_ServerSupportedFeatures                              = 0x2B3A,    ///< Server Supported Features
    BtdrvGattCharacteristicUuidType_PhysicalActivityMonitorFeatures                      = 0x2B3B,    ///< Physical Activity Monitor Features
    BtdrvGattCharacteristicUuidType_GeneralActivityInstantaneousData                     = 0x2B3C,    ///< General Activity Instantaneous Data
    BtdrvGattCharacteristicUuidType_GeneralActivitySummaryData                           = 0x2B3D,    ///< General Activity Summary Data
    BtdrvGattCharacteristicUuidType_CardiorespiratoryActivityInstantaneousData           = 0x2B3E,    ///< CardioRespiratory Activity Instantaneous Data
    BtdrvGattCharacteristicUuidType_CardiorespiratoryActivitySummaryData                 = 0x2B3F,    ///< CardioRespiratory Activity Summary Data
    BtdrvGattCharacteristicUuidType_StepCounterActivitySummaryData                       = 0x2B40,    ///< Step Counter Activity Summary Data
    BtdrvGattCharacteristicUuidType_SleepActivityInstantaneousData                       = 0x2B41,    ///< Sleep Activity Instantaneous Data
    BtdrvGattCharacteristicUuidType_SleepActivitySummaryData                             = 0x2B42,    ///< Sleep Activity Summary Data
    BtdrvGattCharacteristicUuidType_PhysicalActivityMonitorControlPoint                  = 0x2B43,    ///< Physical Activity Monitor Control Point
    BtdrvGattCharacteristicUuidType_ActivityCurrentSession                               = 0x2B44,    ///< Activity Current Session
    BtdrvGattCharacteristicUuidType_PhysicalActivitySessionDescriptor                    = 0x2B45,    ///< Physical Activity Session Descriptor
    BtdrvGattCharacteristicUuidType_PreferredUnits                                       = 0x2B46,    ///< Preferred Units
    BtdrvGattCharacteristicUuidType_HighResolutionHeight                                 = 0x2B47,    ///< High Resolution Height
    BtdrvGattCharacteristicUuidType_MiddleName                                           = 0x2B48,    ///< Middle Name
    BtdrvGattCharacteristicUuidType_StrideLength                                         = 0x2B49,    ///< Stride Length
    BtdrvGattCharacteristicUuidType_Handedness                                           = 0x2B4A,    ///< Handedness
    BtdrvGattCharacteristicUuidType_DeviceWearingPosition                                = 0x2B4B,    ///< Device Wearing Position
    BtdrvGattCharacteristicUuidType_FourZoneHeartRateLimits                              = 0x2B4C,    ///< Four Zone Heart Rate Limits
    BtdrvGattCharacteristicUuidType_HighIntensityExerciseThreshold                       = 0x2B4D,    ///< High Intensity Exercise Threshold
    BtdrvGattCharacteristicUuidType_ActivityGoal                                         = 0x2B4E,    ///< Activity Goal
    BtdrvGattCharacteristicUuidType_SedentaryIntervalNotification                        = 0x2B4F,    ///< Sedentary Interval Notification
    BtdrvGattCharacteristicUuidType_CaloricIntake                                        = 0x2B50,    ///< Caloric Intake
    BtdrvGattCharacteristicUuidType_TmapRole                                             = 0x2B51,    ///< TMAP Role
    BtdrvGattCharacteristicUuidType_AudioInputState                                      = 0x2B77,    ///< Audio Input State
    BtdrvGattCharacteristicUuidType_GainSettingsAttribute                                = 0x2B78,    ///< Gain Settings Attribute
    BtdrvGattCharacteristicUuidType_AudioInputType                                       = 0x2B79,    ///< Audio Input Type
    BtdrvGattCharacteristicUuidType_AudioInputStatus                                     = 0x2B7A,    ///< Audio Input Status
    BtdrvGattCharacteristicUuidType_AudioInputControlPoint                               = 0x2B7B,    ///< Audio Input Control Point
    BtdrvGattCharacteristicUuidType_AudioInputDescription                                = 0x2B7C,    ///< Audio Input Description
    BtdrvGattCharacteristicUuidType_VolumeState                                          = 0x2B7D,    ///< Volume State
    BtdrvGattCharacteristicUuidType_VolumeControlPoint                                   = 0x2B7E,    ///< Volume Control Point
    BtdrvGattCharacteristicUuidType_VolumeFlags                                          = 0x2B7F,    ///< Volume Flags
    BtdrvGattCharacteristicUuidType_VolumeOffsetState                                    = 0x2B80,    ///< Volume Offset State
    BtdrvGattCharacteristicUuidType_AudioLocation                                        = 0x2B81,    ///< Audio Location
    BtdrvGattCharacteristicUuidType_VolumeOffsetControlPoint                             = 0x2B82,    ///< Volume Offset Control Point
    BtdrvGattCharacteristicUuidType_AudioOutputDescription                               = 0x2B83,    ///< Audio Output Description
    BtdrvGattCharacteristicUuidType_SetIdentityResolvingKey                              = 0x2B84,    ///< Set Identity Resolving Key
    BtdrvGattCharacteristicUuidType_CoordinatedSetSize                                   = 0x2B85,    ///< Coordinated Set Size
    BtdrvGattCharacteristicUuidType_SetMemberLock                                        = 0x2B86,    ///< Set Member Lock
    BtdrvGattCharacteristicUuidType_SetMemberRank                                        = 0x2B87,    ///< Set Member Rank
    BtdrvGattCharacteristicUuidType_EncryptedDataKeyMaterial                             = 0x2B88,    ///< Encrypted Data Key Material
    BtdrvGattCharacteristicUuidType_ApparentEnergy32                                     = 0x2B89,    ///< Apparent Energy 32
    BtdrvGattCharacteristicUuidType_ApparentPower                                        = 0x2B8A,    ///< Apparent Power
    BtdrvGattCharacteristicUuidType_LiveHealthObservations                               = 0x2B8B,    ///< Live Health Observations
    BtdrvGattCharacteristicUuidType_CoTextsubscript2Concentration                        = 0x2B8C,    ///< CO\textsubscript{2} Concentration
    BtdrvGattCharacteristicUuidType_CosineOfTheAngle                                     = 0x2B8D,    ///< Cosine of the Angle
    BtdrvGattCharacteristicUuidType_DeviceTimeFeature                                    = 0x2B8E,    ///< Device Time Feature
    BtdrvGattCharacteristicUuidType_DeviceTimeParameters                                 = 0x2B8F,    ///< Device Time Parameters
    BtdrvGattCharacteristicUuidType_DeviceTime                                           = 0x2B90,    ///< Device Time
    BtdrvGattCharacteristicUuidType_DeviceTimeControlPoint                               = 0x2B91,    ///< Device Time Control Point
    BtdrvGattCharacteristicUuidType_TimeChangeLogData                                    = 0x2B92,    ///< Time Change Log Data
    BtdrvGattCharacteristicUuidType_MediaPlayerName                                      = 0x2B93,    ///< Media Player Name
    BtdrvGattCharacteristicUuidType_MediaPlayerIconObjectId                              = 0x2B94,    ///< Media Player Icon Object ID
    BtdrvGattCharacteristicUuidType_MediaPlayerIconUrl                                   = 0x2B95,    ///< Media Player Icon URL
    BtdrvGattCharacteristicUuidType_TrackChanged                                         = 0x2B96,    ///< Track Changed
    BtdrvGattCharacteristicUuidType_TrackTitle                                           = 0x2B97,    ///< Track Title
    BtdrvGattCharacteristicUuidType_TrackDuration                                        = 0x2B98,    ///< Track Duration
    BtdrvGattCharacteristicUuidType_TrackPosition                                        = 0x2B99,    ///< Track Position
    BtdrvGattCharacteristicUuidType_PlaybackSpeed                                        = 0x2B9A,    ///< Playback Speed
    BtdrvGattCharacteristicUuidType_SeekingSpeed                                         = 0x2B9B,    ///< Seeking Speed
    BtdrvGattCharacteristicUuidType_CurrentTrackSegmentsObjectId                         = 0x2B9C,    ///< Current Track Segments Object ID
    BtdrvGattCharacteristicUuidType_CurrentTrackObjectId                                 = 0x2B9D,    ///< Current Track Object ID
    BtdrvGattCharacteristicUuidType_NextTrackObjectId                                    = 0x2B9E,    ///< Next Track Object ID
    BtdrvGattCharacteristicUuidType_ParentGroupObjectId                                  = 0x2B9F,    ///< Parent Group Object ID
    BtdrvGattCharacteristicUuidType_CurrentGroupObjectId                                 = 0x2BA0,    ///< Current Group Object ID
    BtdrvGattCharacteristicUuidType_PlayingOrder                                         = 0x2BA1,    ///< Playing Order
    BtdrvGattCharacteristicUuidType_PlayingOrdersSupported                               = 0x2BA2,    ///< Playing Orders Supported
    BtdrvGattCharacteristicUuidType_MediaState                                           = 0x2BA3,    ///< Media State
    BtdrvGattCharacteristicUuidType_MediaControlPoint                                    = 0x2BA4,    ///< Media Control Point
    BtdrvGattCharacteristicUuidType_MediaControlPointOpcodesSupported                    = 0x2BA5,    ///< Media Control Point Opcodes Supported
    BtdrvGattCharacteristicUuidType_SearchResultsObjectId                                = 0x2BA6,    ///< Search Results Object ID
    BtdrvGattCharacteristicUuidType_SearchControlPoint                                   = 0x2BA7,    ///< Search Control Point
    BtdrvGattCharacteristicUuidType_Energy32                                             = 0x2BA8,    ///< Energy 32
    BtdrvGattCharacteristicUuidType_MediaPlayerIconObjectType                            = 0x2BA9,    ///< Media Player Icon Object Type
    BtdrvGattCharacteristicUuidType_TrackSegmentsObjectType                              = 0x2BAA,    ///< Track Segments Object Type
    BtdrvGattCharacteristicUuidType_TrackObjectType                                      = 0x2BAB,    ///< Track Object Type
    BtdrvGattCharacteristicUuidType_GroupObjectType                                      = 0x2BAC,    ///< Group Object Type
    BtdrvGattCharacteristicUuidType_ConstantToneExtensionEnable                          = 0x2BAD,    ///< Constant Tone Extension Enable
    BtdrvGattCharacteristicUuidType_AdvertisingConstantToneExtensionMinimumLength        = 0x2BAE,    ///< Advertising Constant Tone Extension Minimum Length
    BtdrvGattCharacteristicUuidType_AdvertisingConstantToneExtensionMinimumTransmitCount = 0x2BAF,    ///< Advertising Constant Tone Extension Minimum Transmit Count
    BtdrvGattCharacteristicUuidType_AdvertisingConstantToneExtensionTransmitDuration     = 0x2BB0,    ///< Advertising Constant Tone Extension Transmit Duration
    BtdrvGattCharacteristicUuidType_AdvertisingConstantToneExtensionInterval             = 0x2BB1,    ///< Advertising Constant Tone Extension Interval
    BtdrvGattCharacteristicUuidType_AdvertisingConstantToneExtensionPhy                  = 0x2BB2,    ///< Advertising Constant Tone Extension PHY
    BtdrvGattCharacteristicUuidType_BearerProviderName                                   = 0x2BB3,    ///< Bearer Provider Name
    BtdrvGattCharacteristicUuidType_BearerUci                                            = 0x2BB4,    ///< Bearer UCI
    BtdrvGattCharacteristicUuidType_BearerTechnology                                     = 0x2BB5,    ///< Bearer Technology
    BtdrvGattCharacteristicUuidType_BearerUriSchemesSupportedList                        = 0x2BB6,    ///< Bearer URI Schemes Supported List
    BtdrvGattCharacteristicUuidType_BearerSignalStrength                                 = 0x2BB7,    ///< Bearer Signal Strength
    BtdrvGattCharacteristicUuidType_BearerSignalStrengthReportingInterval                = 0x2BB8,    ///< Bearer Signal Strength Reporting Interval
    BtdrvGattCharacteristicUuidType_BearerListCurrentCalls                               = 0x2BB9,    ///< Bearer List Current Calls
    BtdrvGattCharacteristicUuidType_ContentControlId                                     = 0x2BBA,    ///< Content Control ID
    BtdrvGattCharacteristicUuidType_StatusFlags                                          = 0x2BBB,    ///< Status Flags
    BtdrvGattCharacteristicUuidType_IncomingCallTargetBearerUri                          = 0x2BBC,    ///< Incoming Call Target Bearer URI
    BtdrvGattCharacteristicUuidType_CallState                                            = 0x2BBD,    ///< Call State
    BtdrvGattCharacteristicUuidType_CallControlPoint                                     = 0x2BBE,    ///< Call Control Point
    BtdrvGattCharacteristicUuidType_CallControlPointOptionalOpcodes                      = 0x2BBF,    ///< Call Control Point Optional Opcodes
    BtdrvGattCharacteristicUuidType_TerminationReason                                    = 0x2BC0,    ///< Termination Reason
    BtdrvGattCharacteristicUuidType_IncomingCall                                         = 0x2BC1,    ///< Incoming Call
    BtdrvGattCharacteristicUuidType_CallFriendlyName                                     = 0x2BC2,    ///< Call Friendly Name
    BtdrvGattCharacteristicUuidType_Mute                                                 = 0x2BC3,    ///< Mute
    BtdrvGattCharacteristicUuidType_SinkAse                                              = 0x2BC4,    ///< Sink ASE
    BtdrvGattCharacteristicUuidType_SourceAse                                            = 0x2BC5,    ///< Source ASE
    BtdrvGattCharacteristicUuidType_AseControlPoint                                      = 0x2BC6,    ///< ASE Control Point
    BtdrvGattCharacteristicUuidType_BroadcastAudioScanControlPoint                       = 0x2BC7,    ///< Broadcast Audio Scan Control Point
    BtdrvGattCharacteristicUuidType_BroadcastReceiveState                                = 0x2BC8,    ///< Broadcast Receive State
    BtdrvGattCharacteristicUuidType_SinkPac                                              = 0x2BC9,    ///< Sink PAC
    BtdrvGattCharacteristicUuidType_SinkAudioLocations                                   = 0x2BCA,    ///< Sink Audio Locations
    BtdrvGattCharacteristicUuidType_SourcePac                                            = 0x2BCB,    ///< Source PAC
    BtdrvGattCharacteristicUuidType_SourceAudioLocations                                 = 0x2BCC,    ///< Source Audio Locations
    BtdrvGattCharacteristicUuidType_AvailableAudioContexts                               = 0x2BCD,    ///< Available Audio Contexts
    BtdrvGattCharacteristicUuidType_SupportedAudioContexts                               = 0x2BCE,    ///< Supported Audio Contexts
    BtdrvGattCharacteristicUuidType_AmmoniaConcentration                                 = 0x2BCF,    ///< Ammonia Concentration
    BtdrvGattCharacteristicUuidType_CarbonMonoxideConcentration                          = 0x2BD0,    ///< Carbon Monoxide Concentration
    BtdrvGattCharacteristicUuidType_MethaneConcentration                                 = 0x2BD1,    ///< Methane Concentration
    BtdrvGattCharacteristicUuidType_NitrogenDioxideConcentration                         = 0x2BD2,    ///< Nitrogen Dioxide Concentration
    BtdrvGattCharacteristicUuidType_NonMethaneVolatileOrganicCompoundsConcentration      = 0x2BD3,    ///< Non-Methane Volatile Organic Compounds Concentration
    BtdrvGattCharacteristicUuidType_OzoneConcentration                                   = 0x2BD4,    ///< Ozone Concentration
    BtdrvGattCharacteristicUuidType_ParticulateMatterPm1Concentration                    = 0x2BD5,    ///< Particulate Matter - PM1 Concentration
    BtdrvGattCharacteristicUuidType_ParticulateMatterPm25Concentration                   = 0x2BD6,    ///< Particulate Matter - PM2.5 Concentration
    BtdrvGattCharacteristicUuidType_ParticulateMatterPm10Concentration                   = 0x2BD7,    ///< Particulate Matter - PM10 Concentration
    BtdrvGattCharacteristicUuidType_SulfurDioxideConcentration                           = 0x2BD8,    ///< Sulfur Dioxide Concentration
    BtdrvGattCharacteristicUuidType_SulfurHexafluorideConcentration                      = 0x2BD9,    ///< Sulfur Hexafluoride Concentration
    BtdrvGattCharacteristicUuidType_HearingAidFeatures                                   = 0x2BDA,    ///< Hearing Aid Features
    BtdrvGattCharacteristicUuidType_HearingAidPresetControlPoint                         = 0x2BDB,    ///< Hearing Aid Preset Control Point
    BtdrvGattCharacteristicUuidType_ActivePresetIndex                                    = 0x2BDC,    ///< Active Preset Index
    BtdrvGattCharacteristicUuidType_StoredHealthObservations                             = 0x2BDD,    ///< Stored Health Observations
    BtdrvGattCharacteristicUuidType_FixedString64                                        = 0x2BDE,    ///< Fixed String 64
    BtdrvGattCharacteristicUuidType_HighTemperature                                      = 0x2BDF,    ///< High Temperature
    BtdrvGattCharacteristicUuidType_HighVoltage                                          = 0x2BE0,    ///< High Voltage
    BtdrvGattCharacteristicUuidType_LightDistribution                                    = 0x2BE1,    ///< Light Distribution
    BtdrvGattCharacteristicUuidType_LightOutput                                          = 0x2BE2,    ///< Light Output
    BtdrvGattCharacteristicUuidType_LightSourceType                                      = 0x2BE3,    ///< Light Source Type
    BtdrvGattCharacteristicUuidType_Noise                                                = 0x2BE4,    ///< Noise
    BtdrvGattCharacteristicUuidType_RelativeRuntimeInACorrelatedColorTemperatureRange    = 0x2BE5,    ///< Relative Runtime in a Correlated Color Temperature Range
    BtdrvGattCharacteristicUuidType_TimeSecond32                                         = 0x2BE6,    ///< Time Second 32
    BtdrvGattCharacteristicUuidType_VocConcentration                                     = 0x2BE7,    ///< VOC Concentration
    BtdrvGattCharacteristicUuidType_VoltageFrequency                                     = 0x2BE8,    ///< Voltage Frequency
    BtdrvGattCharacteristicUuidType_BatteryCriticalStatus                                = 0x2BE9,    ///< Battery Critical Status
    BtdrvGattCharacteristicUuidType_BatteryHealthStatus                                  = 0x2BEA,    ///< Battery Health Status
    BtdrvGattCharacteristicUuidType_BatteryHealthInformation                             = 0x2BEB,    ///< Battery Health Information
    BtdrvGattCharacteristicUuidType_BatteryInformation                                   = 0x2BEC,    ///< Battery Information
    BtdrvGattCharacteristicUuidType_BatteryLevelStatus                                   = 0x2BED,    ///< Battery Level Status
    BtdrvGattCharacteristicUuidType_BatteryTimeStatus                                    = 0x2BEE,    ///< Battery Time Status
    BtdrvGattCharacteristicUuidType_EstimatedServiceDate                                 = 0x2BEF,    ///< Estimated Service Date
    BtdrvGattCharacteristicUuidType_BatteryEnergyStatus                                  = 0x2BF0,    ///< Battery Energy Status
    BtdrvGattCharacteristicUuidType_ObservationScheduleChanged                           = 0x2BF1,    ///< Observation Schedule Changed
    BtdrvGattCharacteristicUuidType_CurrentElapsedTime                                   = 0x2BF2,    ///< Current Elapsed Time
    BtdrvGattCharacteristicUuidType_HealthSensorFeatures                                 = 0x2BF3,    ///< Health Sensor Features
    BtdrvGattCharacteristicUuidType_GhsControlPoint                                      = 0x2BF4,    ///< GHS Control Point
    BtdrvGattCharacteristicUuidType_LeGattSecurityLevels                                 = 0x2BF5,    ///< LE GATT Security Levels
    BtdrvGattCharacteristicUuidType_EslAddress                                           = 0x2BF6,    ///< ESL Address
    BtdrvGattCharacteristicUuidType_ApSyncKeyMaterial                                    = 0x2BF7,    ///< AP Sync Key Material
    BtdrvGattCharacteristicUuidType_EslResponseKeyMaterial                               = 0x2BF8,    ///< ESL Response Key Material
    BtdrvGattCharacteristicUuidType_EslCurrentAbsoluteTime                               = 0x2BF9,    ///< ESL Current Absolute Time
    BtdrvGattCharacteristicUuidType_EslDisplayInformation                                = 0x2BFA,    ///< ESL Display Information
    BtdrvGattCharacteristicUuidType_EslImageInformation                                  = 0x2BFB,    ///< ESL Image Information
    BtdrvGattCharacteristicUuidType_EslSensorInformation                                 = 0x2BFC,    ///< ESL Sensor Information
    BtdrvGattCharacteristicUuidType_EslLedInformation                                    = 0x2BFD,    ///< ESL LED Information
    BtdrvGattCharacteristicUuidType_EslControlPoint                                      = 0x2BFE,    ///< ESL Control Point
    BtdrvGattCharacteristicUuidType_UdiForMedicalDevices                                 = 0x2BFF,    ///< UDI for Medical Devices
} BtdrvGattCharacteristicUuidType;

/// GattDescriptorUuidType
typedef enum {
    BtdrvGattDescriptorUuidType_CharacteristicExtendedProperties   = 0x2900,    ///< Characteristic Extended Properties
    BtdrvGattDescriptorUuidType_CharacteristicUserDescription      = 0x2901,    ///< Characteristic User Description
    BtdrvGattDescriptorUuidType_ClientCharacteristicConfiguration  = 0x2902,    ///< Client Characteristic Configuration
    BtdrvGattDescriptorUuidType_ServerCharacteristicConfiguration  = 0x2903,    ///< Server Characteristic Configuration
    BtdrvGattDescriptorUuidType_CharacteristicPresentationFormat   = 0x2904,    ///< Characteristic Presentation Format
    BtdrvGattDescriptorUuidType_CharacteristicAggregateFormat      = 0x2905,    ///< Characteristic Aggregate Format
    BtdrvGattDescriptorUuidType_ValidRange                         = 0x2906,    ///< Valid Range
    BtdrvGattDescriptorUuidType_ExternalReportReference            = 0x2907,    ///< External Report Reference
    BtdrvGattDescriptorUuidType_ReportReference                    = 0x2908,    ///< Report Reference
    BtdrvGattDescriptorUuidType_NumberOfDigitals                   = 0x2909,    ///< Number of Digitals
    BtdrvGattDescriptorUuidType_ValueTriggerSetting                = 0x290A,    ///< Value Trigger Setting
    BtdrvGattDescriptorUuidType_EnvironmentalSensingConfiguration  = 0x290B,    ///< Environmental Sensing Configuration
    BtdrvGattDescriptorUuidType_EnvironmentalSensingMeasurement    = 0x290C,    ///< Environmental Sensing Measurement
    BtdrvGattDescriptorUuidType_EnvironmentalSensingTriggerSetting = 0x290D,    ///< Environmental Sensing Trigger Setting
    BtdrvGattDescriptorUuidType_TimeTriggerSetting                 = 0x290E,    ///< Time Trigger Setting
    BtdrvGattDescriptorUuidType_CompleteBrEdrTransportBlockData    = 0x290F,    ///< Complete BR-EDR Transport Block Data
    BtdrvGattDescriptorUuidType_ObservationSchedule                = 0x2910,    ///< Observation Schedule
    BtdrvGattDescriptorUuidType_ValidRangeAndAccuracy              = 0x2911,    ///< Valid Range and Accuracy
} BtdrvGattDescriptorUuidType;
